(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    127058,       2474]*)
(*NotebookOutlinePosition[    127894,       2500]*)
(*  CellTagsIndexPosition[    127850,       2496]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Style Definitions", "Subtitle"],

Cell["\<\
Modify the definitions below to change the default \
appearance of all cells in a given style.  Make modifications to any \
definition using commands in the Format menu.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Style Environment Names", "Section"],

Cell[StyleData[All, "Working"],
  PageWidth->WindowWidth,
  ScriptMinSize->9],

Cell[StyleData[All, "Printout"],
  PageWidth->PaperWidth,
  ScriptMinSize->7,
  FontSize->10,
  PrivateFontOptions->{"FontType"->"Outline"}]
}, Closed]],

Cell[CellGroupData[{

Cell["Notebook Options", "Section"],

Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],

Cell[StyleData["Notebook"],
  PageHeaders->{{Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
          TextData[ {
            ValueBox[ "FileName"]}], "Header"], None, Cell[ 
          TextData[ {
            CounterBox[ "Page"]}], "PageNumber"]}},
  PageHeaderLines->{True, True},
  PrintingOptions->{"FirstPageHeader"->False,
  "FacingPages"->True},
  CellBracketOptions->{"Color"->RGBColor[0, 0, 0.466667]},
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{

Cell["Header Graphic (to be pasted in)", "Section"],

Cell[CellGroupData[{

Cell[StyleData["HeaderCell"],
  ShowCellBracket->False,
  CellMargins->{{0, 0}, {0, 0}},
  Evaluatable->False,
  PageBreakBelow->False,
  ImageSize->{350, 24},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[BoxData[{
    StyleBox[Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .24231 
%%ImageSize: 300 72.6923 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.00576923 0.47619 [
[ 0 0 0 0 ]
[ 1 .24231 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .24231 L
0 .24231 L
closepath
clip
newpath
% Start of sub-graphic
p
0.0238095 0.00576923 0.404762 0.236538 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00915751 0.0144231 0.00915751 [
[ 0 0 0 0 ]
[ 1 .60577 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .60577 L
0 .60577 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01442 translate
.95238 .57693 scale
312 string
104 63 8 [104 0 0 63 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
000000000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000
0000000000000000000000000000000000000000006D6D6DFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000
000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000
000000000000000000000000000000000000000000000000000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000000000
000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000
000000696969FFFFFFFFFFFF696969000000000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000000000FFFFFFFFFFFF
FFFFFF838383000000000000000000000000686868FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000686868
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000898989FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000686868FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFA7A7A7000000000000000000A7A7A7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000A7A7A7FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFF7474740000000000000000000000008B8B8BFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
79535EDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF8B8B8B0000000000000000000000000000009191916F6F6F
FFFFFF000000000000000000000000000000919191FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
79535EDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6D6D6D000000000000000000000000000000000000
000000000000000000000000000000838383FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
79535EDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000000000000000000000000000000000000000000000000000000000
000000000000000000FFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF919191000000000000000000000000
000000000000000000989898FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
79535EDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
79535EDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
79535EDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
79535EDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
79535EDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
79535EDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
79535EDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
79535EDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CAC3B5CFFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CAC3B5CFFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CAC3B5CFFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CAC3B5CFFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CAC3B5CFFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CAC3B5CFFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CAC3B5CFFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CAC3B5CFFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CAC3B5CFFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CAC3B5CFFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CE22459FFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CE22459FFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CE22459FFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CE22459FFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CE22459FFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CE22459FFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CE22459FFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CE22459FFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CE22459FFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CE22459FFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CE22459FFFFFF
FFFFFFDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AC3B5CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CA7143DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AC3B5CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CA7143DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AC3B5CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CA7143DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AC3B5CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CA7143DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AC3B5CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CA7143DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AC3B5CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CA7143DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AC3B5CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CA7143DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AC3B5CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CA7143DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AC3B5CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CA7143DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AC3B5CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CA7143DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
AC3B5CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023C
DC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CDC023CA7143DFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% Start of sub-graphic
p
0.595238 0.00576923 0.97619 0.236538 MathSubStart
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00952381 0.0190476 0.00952381 [
[ 0 0 0 0 ]
[ 1 .8 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .8 L
0 .8 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .01905 translate
.95238 .7619 scale
300 string
100 80 8 [100 0 0 80 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDF7F7F7F3F3F3F0F0F0
F0F0F0EFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEF
EFEFEFF0F0F0F0F0F0F2F2F2F5F5F5F7F7F7FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDF2F2F2DCDCDCC9C9C9BFBFBF
BEBEBEBDBDBDBDBDBDBBBBBBBABABABABABABABABAB9B9B9BABABABABABABABABABBBBBB
BDBDBDBDBDBDBEBEBEC2C2C2D1D1D1DCDCDCF2F2F2FDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9E1E1E1B4B4B48A8A8A797979
7373737171716E6E6E6767676161615F5F5F5F5F5F5E5E5E5F5F5F5F5F5F616161666666
6D6D6D7272727575757F7F7F9D9D9DB4B4B4E1E1E1F9F9F9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8DEDEDEABABAB7E7E7E696969
6363635A5A5A5151513838382424241C1C1C1B1B1B1A1A1A1B1B1B1E1E1E222222343434
4D4D4D5E5E5E656565707070929292ABABABDEDEDEF8F8F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC01013D01013B01013B010139
01013801013701013601013401013301013201013001012F01012E01012C01012C01012B
010129010127010126323269BEBEBECDCDCDECECECFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE4A4A9148488D454589444487
42428501013801013701013601013501013301013201013001012F01012E04043B17174D
2D2D663D3D7842427C7878A7EBEBEBF0F0F0F9F9F9FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFBFBFB
F5F5F501013A01013901013701013701013501013301013201013001012F0E0E2F4F4F4F
A7A7A7E4E4E4F8F8F8FCFCFCFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
F8F8F801013B01013A0101380101370101360101340101330101310101300E0E2F505050
AAAAAAE7E7E7FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F901013C01013B01013A0101390101370101360101340101330101310F0F30515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F901013D01013D01013B01013B0101390101370101360101340101330F0F30515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F901013F01013E01013D01013B01013B0101390101370101360101340F0F30515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F901014001013F01013E01013D01013C01013B0101390101370101360F0F31515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F901014201014101013F01013E01013D01013C01013B0101390101370F0F31515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F901014301014301014101013F01013E01013D01013C01013B0101390F0F31515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F901014501014401014301014101013F01013E01013D01013C01013B0F0F32515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F901014701014601014401014301014101013F01013E01013D01013B0F0F32515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F901014701014701014501014301014201014001013F01013D01013C0F0F32515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFCFCFCF9F9F9F8F8F8F7F7F7F8F8F8F9F9F9FBFBFB
FDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F901014901014801014701014501014301014201014001013F01013D0F0F32515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFEFEFEFDFDFDFBFBFBF8F8F8F8F8F8F8F8F8F9F9F9
FCFCFCFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFBFBFBFBFBFBFBFBFB
F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9F9
F9F9F9FBFBFBFBFBFBFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDF7F7F7F3F3F3EBEBEBE2E2E2DADADAD5D5D5D2D2D2D5D5D5DADADADFDFDF
E7E7E7F2F2F2F8F8F8FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F901014A01014901014801014701014501014301014201014001013F0F0F33515151
AAAAAAE7E7E7FBFBFBFBFBFBF4F4F4F0F0F0E7E7E7E0E0E0DADADAD7D7D7D8D8D8DEDEDE
E5E5E5EAEAEAF3F3F3F9F9F9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF9F9F9EFEFEFE9E9E9E0E0E0DCDCDCDCDCDC
DBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDBDADADADBDBDBDBDBDBDBDBDBDBDBDBDBDBDB
DBDBDBDCDCDCDEDEDEE4E4E4F0F0F0FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EDEDEDD6D6D6CACACAB1B1B19D9D9D909090868686828282868686919191989898
ABABABC3C3C3DCDCDCEFEFEFFBFBFBFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902024B01014B0101490101470101460101450101430101420101400F0F33515151
A9A9A9E4E4E4F0F0F0E3E3E3CFCFCFC4C4C4B2B2B2A4A4A49B9B9B9696969696969C9C9C
A8A8A8B1B1B1C6C6C6DCDCDCEDEDEDF8F8F8FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCEDEDEDCDCDCDBBBBBBA2A2A2989898969696
9595959393939090908E8E8E8E8E8E8E8E8E8D8D8D8E8E8E8E8E8E909090939393959595
9696969797979C9C9CB0B0B0D4D4D4F2F2F2FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB
E9E9E9C3C3C39494947D7D7D5B5B5B4545453939393232323030303434343E3E3E454545
5A5A5A7878789E9E9EC6C6C6E6E6E6F8F8F8FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902024D02024C01014B0101490101470101460101440101430101410E0E32505050
A5A5A5D6D6D6CECECEB0B0B09393938888887D7D7D7A7A7A7979797474746E6E6E686868
6767676A6A6A7C7C7C9A9A9ABFBFBFDFDFDFF3F3F3FCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBE3E3E3B3B3B3989898717171646464606060
5A5A5A4D4D4D3F3F3F3838383737373737373636363737373939394040404F4F4F5C5C5C
5F5F5F6262626A6A6A878787BDBDBDEAEAEAFCFCFCFFFFFFFFFFFFFFFFFFFDFDFDEFEFEF
C7C7C787878730306117176102026B02026902026902026702026504046314144E262635
3838384646465F5F5F888888BBBBBBE4E4E4F2F2F2FDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902024F02024E02024C01014B0101490101470101460101440101430E0E334C4C4C
969696B1B1B19898987B7B7B3D3D6F2424630101360101340101330101311D1D59515178
626262555555454545505050727272A3A3A3CFCFCFEDEDEDFBFBFBFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC020286020286020286020285020285020284
02028402028302028302028302028302028202028102028002028002027F02027F02027E
02027D02027C02027B9C9C9CC9C9C9EEEEEEFDFDFDFFFFFFFFFFFFFFFFFFF9F9F9DFDFDF
66669B02027002026E02026D02026D02026B02026A020269020268020266020264020264
0202635454645656565F5F5F878787C1C1C1D9D9D9F6F6F6FEFEFEFFFFFFFFFFFFFFFFFF
F9F9F902025002024F02024E02024C01014B0101490101470101460101440D0D32424242
7979798181810B0B4D01013B01013A0101390101373F3F8014145201013201013001012F
01012D01012C37374F2B2B2B323232585858919191C6C6C6EBEBEBF5F5F5FEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE020288020288020287020287020287020287
02028702028602028502028502028402028402028302028302028202028102028002027F
02027F02027F02027ED5D5D5E9E9E9F8F8F8FEFEFEFFFFFFFFFFFFFFFFFFF5F5F59D9DC2
02027202027102027002027002026E02026D02026C02026A020269020268020266020265
0202640202632A2A7F676767686868989898B7B7B7E7E7E7FCFCFCFFFFFFFFFFFFFFFFFF
F9F9F902025102025102024F02024E02024C01014A0101480101470101450A0A2E303030
40405C01013F01013E535387CACACADADADAEEEEEEF7F7F7F9F9F9FBFBFBF7F7F7161650
01012E01012D01012C01012B1515152222224C4C4C8A8A8AC7C7C7DEDEDEF7F7F7FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF9F9F9F8F8F8F5F5F5F3F3F3EAEAEA
020288020288020287020287020287020286020285020284020284333333868686D0D0D0
E4E4E4F2F2F2F4F4F4F6F6F6FBFBFBFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEF2F2F2020275
02027502027302027202027102027002026F02026D02026C1A1A648B8B8BCECECEE1E1E1
7C7CBF0202640202635F5F916F6F6F8181819D9D9DD8D8D8F7F7F7FFFFFFFFFFFFFFFFFF
F9F9F902025302025202025002024F02024D02024B01014A01014801014707072B1A1A27
010143010141989898CECECEEEEEEEF6F6F6FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
01012F01012F01012C01012C01012A0B0B151E1E1E4D4D4D929292B4B4B4E5E5E5F9F9F9
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFCFCFCFBFBFBF2F2F2
0202890202890202880202880202870202870202870202860202853535358A8A8AD7D7D7
EBEBEBF9F9F9FCFCFCFCFCFCFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF0F0F0020276
02027502027402027302027202027102027002026E02026D444444999999DCDCDCEDEDED
F7F7F74848A30202640202628080808484849B9B9BD5D5D5F6F6F6FFFFFFFFFFFFFFFFFF
F9F9F902025402025302025102024F02024E02024C01014B01014901014704042905054B
010143464670AEAEAEE0E0E0F7F7F7FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
7F7FB201012F01012D01012C01012B010131111111343434747474999999D7D7D7F5F5F5
FEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
02028B02028B02028B02028A02028A0202890202880202870202873636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF020279
02027802027502027502027402027202027102027007075C4D4D4DA6A6A6E6E6E6F5F5F5
FEFEFEFEFEFE4949A40202648686A9A7A7A7B4B4B4DCDCDCF7F7F7FFFFFFFFFFFFFFFFFF
F9F9F902025502025402025302025102024F02024E02024C01014B010148030331010146
161659919191D2D2D2F4F4F4FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7F746468401012E01012C01012C01012A010133141414404040636363AEAEAEE4E4E4
FBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
02028E02028D02028C02028C02028B02028B02028B02028A0202893636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF02027B
02027A0202780202760202750202750202730202710E0E3C505050AAAAAAE7E7E7F6F6F6
FFFFFFFFFFFFFDFDFD020265020264D8D8D8DEDEDEEFEFEFFCFCFCFFFFFFFFFFFFFFFFFF
F9F9F902025702025602025402025202025002024F02024D02024B01014A010149010147
616161B3B3B3E9E9E9FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9B5B5D101012F01012E01012C01012B0101290505231F1F1F373737808080C9C9C9
F2F2F2FEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
02029002029002029002028E02028E02028D02028C02028B02028B3636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF02027D
02027B02027A0202790202780202760202750202730F0F3D515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFA2A2D7F8F8F8F7F7F7F8F8F8FCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902025802025702025502025402025202025002024F02024D02024B01014B1E1E46
7D7D7DCDCDCDF5F5F5FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013001012F01012D01012C01012A0101280D0D0D1B1B1B545454A6A6A6
E2E2E2FBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
03039303039202029102029102029002029002029002028E02028D3636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF02027F
02027D02027C02027A02027A0202790202760202750F0F3D515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902025902025802025702025502025402025202024F02024E02024C02024B3D3D3D
949494DCDCDCF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013101012F01012E01012C01012B0101290101300C0C0C333333808080
CDCDCDF4F4F4FEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303950303950303940303930303930303920202910202900202903636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF020280
02027F02027E02027C02027B02027A0202790202760F0F3D515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902025B02025A02025802025602025402025302025102024F02024E02024D494949
A2A2A2E4E4E4FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013301013001012F01012D01012C01012A0101280101301E1E1E5E5E5E
B4B4B4EBEBEBFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303970303960303960303950303950303950303940303930303923636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF020282
02028102027F02027E02027D02027C02027A0202790F0F3D515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902025C02025B02025902025802025602025402025302025002024F07074D4F4F4F
A8A8A8E7E7E7FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013301013201012F01012E01012C01012B010129010128111111444444
9A9A9ADFDFDFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303990303990303980303970303970303960303950303950303943636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF020283
02028302028102027F02027F02027E02027C02027A0F0F3D515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902025D02025C02025B0202590202570202550202540202520202500E0E35505050
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013401013301013101012F01012D01012C01012A01012906062C323232
848484D2D2D2F7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
03039B03039A03039A0303990303990303990303980303970303963636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF020285
02028402028302028102028102027F02027E02027C0F0F3D515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902025E02025D02025C02025A0202580202570202550202530202510F0F36515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013601013301013201013001012E01012C01012B01012A010128272727
727272C7C7C7F4F4F4FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
03039C03039C03039B03039A03039A0303990303990303980303973636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF020286
02028502028302028202028202028002027F02027D0F0F3E515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902025F02025E02025C02025B0202590202570202550202540202520F0F36515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013601013401013201013001012F01012C01012C01012B010128222222
6C6C6CC3C3C3F3F3F3FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
03039E03039D03039D03039D03039C03039B03039A0303990303993636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF020288
02028702028502028302028302028202028002027F0F0F3E515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026002026002025E02025C02025A0202580202570202540202530F0F37515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013701013501013301013101012F01012E01012C01012C01012A1D1D1D
636363BDBDBDF0F0F0FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303A10303A103039F03039E03039E03039D03039D03039C03039B3636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF02028A
0202880202870202850202840202830202820202800F0F3E515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026102026002025F02025D02025C0202590202580202560202540F0F37515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013801013601013401013201013001012F01012C01012C01012B1B1B1B
616161BABABAEFEFEFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303A30303A20303A20303A20303A103039F03039E03039D03039D3636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF02028B
02028A0202880202870202860202850202830202820F0F3F515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026302026202026002025E02025C02025B0202590202570202550F0F37515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013901013701013501013301013101012F01012D01012C01012C1E1E1E
646464BEBEBEF0F0F0FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303A60303A50303A40303A30303A30303A20303A203039F03039E3636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF02028D
02028B02028A0202880202870202870202850202830F0F3F515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026402026302026102026002025D02025C02025A0202580202560F0F37515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013A01013801013601013401013201013001012E01012D01012C232323
6E6E6EC4C4C4F3F3F3FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303A70303A60303A60303A60303A50303A40303A30303A20303A23636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF020290
02028D02028B02028A0202890202870202860202850F0F3F515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026502026402026202026002025F02025D02025B0202590202580F0F38515151
AAAAAAE9E9E9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013B01013901013701013501013301013101012F01012E01012C2D2D2D
7E7E7ECECECEF6F6F6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303AA0303A90303A80303A70303A70303A60303A50303A40303A33636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF020291
02029002028D02028B02028B0202890202870202860F0F3F515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026602026502026402026102026002025E02025C02025A0202580E0E37505050
AAAAAAE7E7E7FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013B01013A01013701013601013301013201012F01012F01012D3D3D3D
929292DADADAF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303AB0303AB0303AA0303A90303A90303A80303A70303A60303A53636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF030393
02029102029002028D02028C02028B0202890202870F0F40515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026802026602026402026302026102025F02025D02025C0202590E0E364D4D4D
A6A6A6E6E6E6FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013C01013B01013801013701013401013301013001012F01012E545454
AAAAAAE7E7E7FCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303AE0303AD0303AC0303AB0303AB0303AA0303A90303A80303A73636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF030394
03039302029102029002028E02028C02028B0202890F0F40515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026902026802026502026402026202026002025E02025C02025A0B0B34434343
9A9A9ADFDFDFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013D01013B0101390101370101350101330101310101300E0E45737373
C4C4C4F2F2F2FEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303B00303AE0303AD0303AC0303AC0303AB0303AA0303A90303A83636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF030395
03039403039202029002029002028D02028B02028A0F0F40515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026902026802026602026402026202026002025F02025C02025B0A0A323C3C3C
909090D8D8D8F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013D01013B01013A010137010136010133010132010131232347858585
D0D0D0F5F5F5FEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303B20303B10303B00303B00303AE0303AD0303AC0303AB0303AA3636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF030396
03039503039302029102029002029002028C02028B0F0F40515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026A02026902026702026502026402026102026002025E02025C06063B2A2A2A
727272C1C1C1EEEEEEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9EFEFEF01013E01013C01013B0101380101370101340101330101325A5A5AABABAB
E5E5E5FBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303B40303B30303B20303B10303B00303B00303AE0303AD0303AB3636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF030398
03039603039503039303039202029002028E02028C0F0F41515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026B02026A02026902026602026402026302026002025F02025C02025C1E1E1E
5555559E9E9ED9D9D9F6F6F6FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8F8F8EDEDED01013F01013D01013B0101390101370101350101330C0C48868686CECECE
F3F3F3FEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6
0303B50303B50303B40303B30303B30303B20303B00303B00303AE3636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFCFCFCF8F8F8EAEAEA030399
03039803039603039503039403039202029002028E0E0E404F4F4FA7A7A7E3E3E3F0F0F0
F9F9F9FBFBFBFBFBFBFBFBFBFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F902026C02026B02026902026802026502026402026102026002025E02025C202020
4848487C7C7CB6B6B6E2E2E2F7F7F7FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F5F5F5E7E7E701013F01013D01013C01013A0101380101360F0F4C6C6C6CB6B6B6E7E7E7
FCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFDFDFDF4F4F4
0404B80404B70404B60303B50303B40303B40303B30303B10303B03636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFFFFFFFDFDFDF4F4F4EEEEEEE2E2E2DBDBDBCDCDCD03039B
0303990303980303960303950303940202910202900C0C3F454545929292C6C6C6D2D2D2
DADADADBDBDBDCDCDCE1E1E1ECECECF8F8F8FCFCFCFFFFFFFFFFFFFEFEFEFEFEFEFDFDFD
F7F7F702026D02026C02026A02026902026602026402026302026002025F02025D02025C
5555556E6E6E8E8E8EBDBDBDE3E3E3EEEEEEFBFBFBFEFEFEFFFFFFFFFFFFFFFFFFFDFDFD
EDEDEDD9D9D901014001013E01013D01013B010139010137828282A5A5A5DCDCDCF7F7F7
FEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCF5F5F5F2F2F2ECECECE9E9E9E1E1E1
0404B90404B80404B80404B70404B70303B50303B40303B40303B23636368D8D8DDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFEFEFEF6F6F6DEDEDECBCBCBA8A8A895959588888803039C
03039A03039903039703039603039503039302029109093B2E2E2E6161618484848B8B8B
919191929292959595A4A4A4C4C4C4E7E7E7F4F4F4FDFDFDF9F9F9F3F3F3ECECECEAEAEA
E4E4E402026E02026D02026B0202690202670202650202640202610202600C0C3702025C
2323747F7F7F7B7B7B909090B7B7B7CACACAE5E5E5F3F3F3F8F8F8FBFBFBF8F8F8EFEFEF
D4D4D47676A301014001013F01013D01013B0101396E6E7DBDBDBDD5D5D5F3F3F3FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDF2F2F2D9D9D9CCCCCCB7B7B7B0B0B0A9A9A9
0404BD0404BB0404BA0404B90404B80404B80404B60303B50303B43838388E8E8EDADADA
EFEFEFFEFEFEFFFFFFFFFFFFFEFEFEF0F0F0C6C6C6A8A8A86E6E6E52525246464603039D
03039C03039A030399030398030396030395030392050537181818323232444444484848
4A4A4A4B4B4B5050506767679D9D9DD8D8D8EBEBEBF8F8F8EBEBEBD0D0D0B9B9B9B1B1B1
ABABAB02026F02026E02026C02026A0202690202660202640202620202600F0F3A31315F
02025C6B6B9B8E8E8E7D7D7D888888969696B5B5B5CDCDCDDADADADFDFDFD9D9D9C6C6C6
A1A1A10D0D5601014101013F01013D01013C54547DBDBDBDE5E5E5F2F2F2FDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBE5E5E5B9B9B99F9F9F7C7C7C6E6E6E6A6A6A
0404BE0404BD0404BD0404BB0404BA0404B90404B80404B70404B6414141949494DCDCDC
F0F0F0FEFEFEFFFFFFFFFFFFFEFEFE9A9ADC0303A70303A60303A50303A30303A203039F
03039D03039C03039A03039903039703039503039403039202029002028D02028B02028B
0202890202870202856D6D6DA1A1A1D9D9D9EBEBEBF4F4F4D9D9D9A7A7A77F7F7F6F6F6F
6B6B6B02027002026F02026D02026B020269020267020265020263020261161641595959
32328602025A39398A9898988181817E7E7E8484849292929D9D9DA1A1A1989898858585
0B0B5501014401014201014001013E61618AC6C6C6E7E7E7F9F9F9FDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB9494DA7878BE6767AC50509448488B464689
0404C10404C00404BF0404BD0404BD0404BB0404BA0404B80404B8666666A9A9A9E4E4E4
F4F4F4FEFEFEFFFFFFFFFFFFFFFFFF9E9EE10303A90303A80303A60303A50303A30303A1
03039E03039D03039B03039A03039903039703039503039302029102029002028C02028B
02028A020288020286AEAEAECBCBCBEBEBEBF4F4F4F5F5F58B8BC36B6BA252528648487C
46467A02027102027002026E02026C02026A02026802026602026402026231315F7B7B7B
BEBEBE5F5FAA0202590202579999A99E9E9E8A8A8A7F7F7F7B7B7B767676717171151560
0101460101440101430101409F9FAED7D7D7EEEEEEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC0404C60404C50404C50404C40404C30404C2
0404C20404C10404C00404BE0404BE0404BD0404BB0404B90404B8858585BBBBBBEAEAEA
F6F6F6FFFFFFFFFFFFFFFFFFFFFFFFA1A1E30303AA0303A90303A70303A50303A30303A2
03039F03039D03039C03039B03039903039703039503039403039202029002028D02028C
02028B020288020287CFCFCFE0E0E0F3F3F3F8F8F8F7F7F702027C02027A020278020275
02027302027102027002026E02026D02026A020269020266020264020262484879969696
CCCCCCEEEEEE1717720202580202554D4D95A4A4A49191918686867F7F7F26266E010148
010146010145010143616197D5D5D5EBEBEBF8F8F8FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE0404C70404C70404C60404C60404C60404C5
0404C30404C20404C20404C10404C00404BF0404BD0404BD0404BACCCCCCE3E3E3F6F6F6
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCF9F9F9F6F6F6F2F2F2E4E4E40303A3
0303A203039F03039D03039C03039A0303990303960E0E414D4D4DA2A2A2DEDEDEEAEAEA
F3F3F3F4F4F4F4F4F4F5F5F5F9F9F9FDFDFDFEFEFEFDFDFD02027D02027A020279020276
02027402027202027102026F02026D02026B0202690202670202650202637D7DAED2D2D2
EAEAEAF9F9F9FDFDFDDBDBED02025602025502025302025102024F02024D01014B010148
2727746D6DA6DFDFDFECECECF6F6F6FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCF9F9F9F7F7F7F7F7F7F7F7F7
F6F6F6F6F6F6F6F6F6F5F5F5F4F4F4F4F4F4F3F3F3F2F2F2F2F2F2F4F4F4F9F9F9FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDEEEEEE0303A4
0303A20303A103039E03039D03039B0303990303980F0F42505050AAAAAAE7E7E7F5F5F5
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBF8F8F8F7F7F7
F7F7F7F6F6F6F6F6F6F6F6F6F5F5F5F4F4F4F4F4F4F3F3F3F2F2F2F2F2F2F2F2F2F6F6F6
FBFBFBFEFEFEFFFFFFFFFFFFFEFEFEFDFDFDF8F8F8B9B9DA9999C9EDEDEDEDEDEDF0F0F0
F4F4F4F6F6F6FBFBFBFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF0303A6
0303A40303A203039F03039E03039D03039A0303990F0F43515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF0303A6
0303A50303A30303A203039F03039D03039C0303990F0F43515151AAAAAAE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEFEFEF0303A8
0303A60303A40303A20303A203039E03039D03039B0F0F44515151ABABABE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF0F0F00303A9
0303A70303A50303A30303A20303A103039D03039C131348555555ACACACE9E9E9F6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF4F4F40303AA
0303A80303A60303A40303A30303A203039E03039D23235C696969B6B6B6ECECECF7F7F7
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFBFBFBF5F5F5F2F2F2EDEDEDEEEEEEF4F4F4F9F9F9FEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F90303AB
0303A90303A70303A50303A40303A203039F03039D4E4E899A9A9ACECECEF2F2F2FBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCF3F3F3E5E5E5DFDFDFD7D7D7D9D9D9E4E4E4F0F0F0FBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC0303AB
0303AA0303A70303A60303A50303A20303A103039D6969A6B9B9B9DEDEDEF6F6F6FCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBEDEDEDCFCFCFAAAAAA9B9B9B8A8A8A8E8E8EA6A6A6C9C9C9E9E9E9F9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
D8D8EF9999DB9797D99797D84646BF4646BF03039E9292D1EAEAEAF5F5F5FDFDFDFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD
F0F0F0CCCCCC9292925B5B5B4949493737373B3B3B545454868686C1C1C1EBEBEBFCFCFC
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFEFEFEFEFEFEFDFDFDFCFCFCFCFCFCFCFCFCFDFDFDFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8
DCDCDC8B8BA30404C90404C90404C90404C90B0B321D1D1D4747478E8E8ED2D2D2F5F5F5
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF3F3F3
B0B0C70404C90404C90404C90404C90404C90404C9070758232323656565B8B8B8EDEDED
F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEEEEEE
0404C90404C90404C90404C90404C90404C90404C90404C9171717525252A9A9A9E7E7E7
F6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEEEEEEE
0404C90404C90404C90404C90404C90404C90404C90404C90F0F62555555ACACACE9E9E9
F6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE9C9CE5
0404C90404C90404C90404C90404C90404C90404C90404C9101092707070C0C0C0EFEFEF
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9
0404C90404C90404C90404C90404C90404C90404C90404C93D3D7F9F9F9FDBDBDBF7F7F7
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
0404C90404C90404C90404C90404C90404C90404C90404C97E7E7EBABABAE7E7E7FBFBFB
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
A1A1E90404C90404C90404C90404C90404C90404C93131BAC3C3C3E4E4E4F8F8F8FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFBFBFEF0404C90404C90404C90404C98787CFE0E0E0EEEEEEF9F9F9FEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFBFBFBF8F8F8F6F6F6F7F7F7FBFBFBFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF
pop
P
% End of image
MathSubEnd
P
% End of sub-graphic
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
        GeneratedCell->False,
        CellAutoOverwrite->False,
        ImageSize->{325, 78.6875},
        ImageMargins->{{228, 0}, {0, 10}},
        ImageRegion->{{0, 1}, {0, 1}},
        ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000550000CQ000`40O003h00OogooAWoo003oOom6
Ool00?moodIoo`00ogooAWoo0018Ool5000>Ool8000@Ool90039Ool004Qoo`D000aoo`/00003=Jeo
ogoo00Uoo`d008Ioo`AkgPYg_@EkgRmoo`00B7oo1@002goo3P002Goo3`00Q7oo00=kgVmkIcT03Ukg
00=S66]JKg/0;goo0018Ool5000:Ool60002=Jd2Ool00cF]000000030007Ool70003Ool00d8@0000
000300000cF]Oomoo`21Ool01W>LF]I6<Cg_>Lhe[@8aS0D]J`07<H`e[CW>>LhmkdicF]H0;goo0018
Ool5000:Ool60002=Jd2Ool00cF]000000030007Ool70003Ool00d8@0000000300000cF]Oomoo`21
Ool500L500H500D200@00aS=G_MW>@0_Ool004Qoo`D000Yoo`@00003=Jeoogoo00Eoo`@000Ioo`H0
00Moo`D008=oo`039C8U<B4A008Q40H01P801@0724TD[1c_8@lmm7NmNmh0;goo0018Ool50009Ool5
0008Ool40002AS44Ool500000cF]Oomoo`07Ool30027Ool00g_N00L01P0500H010059BUBU7>L<goo
0018Ool50009Ool4000:Ool50004Ool5000:Ool30028Ool200L600H00bU:E[EcW00cOol004Qoo`D0
00Uoo`@000Yoo`D000=oo`@000aoo`<008Qoo`<01`D01P03:DYF]GNm03=oo`00B7oo1@002Goo1000
2Woo1@000goo100037oo0`00R7oo1007100600<YBUJeMkd0<goo0018Ool50009Ool4000:Ool50003
Ool40007Ool80028Ool500L300H00bU:E[Eg_@0cOol004Qoo`D000Uoo`@000Yoo`D000=oo`@000Mo
o`P008Qoo`H01`801P03:DYF]GNm03=oo`00B7oo1@002Goo10002Woo1@000goo10001goo2000R7oo
0P081P0700<YBUJeMkd0<goo0018Ool50009Ool4000:Ool50003Ool40007Ool80028Ool300P500L0
0bU:E[Eg_@0cOol004Qoo`D000Uoo`@000Yoo`D000=oo`@009Moo`@020@01`03:DYF]GNm03=oo`00
B7oo1@002Goo10002Woo1@000goo1000Ugoo1@080`0700<YBUJeMkd0<goo0018Ool50009Ool4000:
Ool50003Ool40028Ool00g_NOomoo`0<Ool00`0900P0200300P200L00bU:E[Eg_@0cOol004Qoo`D0
00Uoo`@000Yoo`D000=oo`04DY@000000002DYB0Ool2Nmh00gNmLia_N`02JeX2Kg/00g>LNmioo`09
Ool200T500P01007:DYF]G>L0Woo0W_N00=cW6mkJeX00Vmk00=cW7NmOol09goo0018Ool50009Ool4
000:Ool50004Ool5000:Ool3001HOol2Mkd00g>LKg]_N`0=Kg/00g>LOomoo`05Ool01WNmJeYW>E[F
CW=:DP924006BU9>LeJeHaQ_NgNm27oo0P091P0800TYBUJeLiakgW>LIcUS65:DCW<00TYB00E>LeJe
F]I_NgNm02Ioo`00B7oo1@002Goo10002Woo1@0017oo1@002Woo0`00Egoo00Eg_FLiG_MBU4ic00=:
DPE6<@E:DP03CW=JeW_N00Ioo`06HaQ:DSg_;F/Q21cW0QS600LLib48;F/mkdicHaQcW007Ool300T5
00P01bU:DYA[FVLiF]I:DTHa008mk`09>Lhe[CF]<H`e[DicG_M_Ng_N02Aoo`00B7oo1@002Goo1000
2Woo1@0017oo1@0000=BU7ooOol01Goo1@00Egoo3@0@1P0?00=>LgNmOol017oo00=_N`0>00d01P0=
0`0<00HYC2U:;F]246mkNmh5Ool500T300P01248?Nm240@Y0`0700@Ll0Q:00H01P<01@075:DHaRe[
BU9S67NmNmh08Goo0018Ool50009Ool4000:Ool50004Ool00cW>0000000300000dHaOomoo`04Ool5
001GOol2014=010400l00f]JOomoo`03Ool00g_NCWP03P0200h500d400`01AB_<H`e[E[FLi`01Goo
00<02P0900T00`090P0800PHaR4;00L01bU@IcU_Ng_N0Woo00=kgPQ:00D00P0500L8@Q249BU6<F<H
Kg]kgP0POol004Qoo`D000Uoo`@000Yoo`D000Aoo`03>Lh0000000<00003AS5oogoo00Aoo`D005Yo
o`9kgP804@H040046<I246]JLi`3Nmh5Ool00g_N00h03P0300h300d010a/IcUcW3gg0P0<00D]LSF]
CW=_Ng_N00Aoo`802PD02@0800P<I00800Q>LfLiMkekgPEoo`@01@06128<HbDYBU9JeW>L87oo000I
Ool2?D/HK0L@Ool?0004Ool4000:Ool50005Ool00dHa0000000400000dYB=Jeoo`0600000dYBOomo
o`1JOol40144010011S6AS5[FWNm27oo00=kgP0>00h0100>0P0=00DQ26mkMkekgRDd00803004@Q1>
Lf]JNmh4Ool200X500T01`0800T0224>E[EcW7_N00Ioo`0:?OH01@0500D01PQ26<HicTicJeXPOol0
01Uoo`8mBaQ/1a1oo`l000Aoo`@000Yoo`D000Ioo`03=Jd0000000/00003@Q1oogoo05]oo`L04@05
010HaTHaKg]g_@08Ool00gNm00l03P0500h0100;9BUcW7_N0Woo00HU=00<@QEJeVmkNmh4Ool300X5
00T01@0824]:DV]JNmh01goo00=kgR4@00D00P0500D01PQ28@PaS5Je021oo`006Goo0Se;66`747oo
3`0017oo10002Woo1@002Goo00=:DP0000001@000TicGgoo200A00@HaTHaKg]g_@Qoo`03Mkd03`0?
00D03P0412LYBW>LNmh3Ool200`00fmkMkeoo`04Ool400X400T01008<HaJeWNm2Goo00=JfP0500D0
0P0500D010aS6<I247_N01moo`006Goo0Se;66`7Z7oo0`0B1@0A00@HaTHaKg]g_@Qoo`03Mkd03`0?
00803`<03P0412LYBWNmNmh3Ool00e:JOomoo`06Ool500X300T010aX?NmW>G_N2Goo00=g_@0500D0
0`0500@48@aS:DYcW1moo`006Goo0Se;66`7Z7oo1`0B00D04AS6AS5_NgNm00Qoo`03Mkd03`0?00<0
3`803P0412LYBWNmNmh<Ool00`0;00X02P0200X300T00acWBU9_N`0:Ool00gNm00D01@0300D01@06
124HaVLiNmh07Woo000IOol2?D/HK0NXOol8018011S6AS5_NgNm27oo00=g_@0@00l01@0?00@49bU:
MkekgPaoo`<02`@02P0400TU:EJeLi`:Ool00gNm00H01@0500D00`Q2CW=_N`0NOol001Uoo`8mBaQ/
1jQoo`<04`D04P046<I6<FmkMkd8Ool00gNm0100400500l010@W:DYg_G_N37oo0`0;1@0:00<YBUJe
Mkd02Woo00=g_@0600H01P0500=246]JNmh07Goo000IOol2?D/HK0NXOol701<01@0B6<I6<FmkMkd0
27oo00=g_@0@01000P0@0`0?00@49bU:MkekgPaoo`@02`@02P03:DYF]GNm00Yoo`04Mkd01P0600H5
00D00cW>HaQkgP0MOol001Uoo`8mBaQ/1jQoo`P04`046<I6<FmkMkd8Ool00gNm01004003010200l0
10@W:DYg_G_N37oo100;100:00<YBUJeMkd02Woo00Ag_@0600H01PD01@03=JeS67_N01eoo`006Goo
0Se;66`7Z7oo200C00@HaTHaKg]g_@Qoo`03Mkd04@0@00@0400500l49bU:MkekgP0<Ool00`0<00/0
2`0200/300X00bU:E[Eg_@0:Ool017Nm00H01P061@0500<aS5kgNmh07Goo000IOol2?D/HK0NXOol2
01@601<011S6AS5_NgNm27oo00=g_@0A01001@0@00@49bU:MkekgPaoo`0300`02`0;00<02`802P03
:DYF]GNm00Yoo`03Mkd01P0600801P@01@03<HaNmgNm01eoo`006Goo0Se;66`7Z7oo1@0D0`0C00@H
aTHaKg]g_@Qoo`03Mkd04@0A00D0400412LYBWNmNmh<Ool200`400/200X00bU:E[Eg_@0:Ool00gNm
00H01P0200H400D00c6<G_MkgP0MOol000aooc=/1`04E>]oogooOolGK0N1Ool701@01@0C6<I6<Fmk
Mkd027oo00Ag_@0A01404@@0400412LYBWNmNmh<Ool300`400/0100::DYF]GNm2Woo00=g_@0700H0
0`060`0500<e[F<HNmh07Goo000<OolcK0L015C[Oomoogoo5f`7PGoo0`0E1@0D00@HaTHaKg]g_@Qo
o`03Mkd04P0A00<04@80400412LYBWNmNmh<Ool400`400/00bU:E[EcW00:Ool00gNm00L01P0300H3
00D00dYBKg]oo`0MOol000aooc=/1`04E>]oogooOolGK0N1Ool601D201@011S6AS5_NgNm27oo00=g
_@0B0180100A00D040@X:DYg_G_N00aoo`@030@02`039BUBU7>L00Yoo`03Mkd01`0700@01P801@03
E[EcW7oo01eoo`0037oo<f`700ADjgooOomooaM/1h5oo`P05@046<I6<FmkMkd8Ool017Nm01804P0B
100A00@4:2U:MkekgPaoo`0300d0300<008030<02`038@Q>Lfmk00Yoo`03Mkd01`0700D01P0312QS
67_N01ioo`0037oo<f`700ADjgooOomooaM/1h5oo`0301H05@0E00D05@046<I6<FmkMkd8Ool00gNm
01804P020183014010@X:DYg_G_N37oo00<03@0<00`00P0<0`0;00<LidYBKg/02Woo00=g_@0700L0
1@0600<@R6]JNmh07Woo000<OolcK0L015C[Oomoogoo5f`7PGoo100F100E00@HaTHaKg]g_@Qoo`03
Mkd04P0B00<04P804@0412PYBWNmNmh<Ool00`0=00`0300300`200/011BU>LiS67Nm2Goo00Ag_@07
00L01`@01P03;F]cW7oo01ioo`0037oo<f`700ADjgooOomooaM/1h5oo`H05P805@046<I6<FmkMkd8
Ool00gNm01<04P030182014010@X:DYg_G_N37oo0P0=100<0P0;00D<HbU:CW=_Ng_N00Qoo`04Mkd0
1`0700L300H00`@Y@Q1kgP0OOol000aooc=/1`04E>]oogooOolGK0N1Ool801H011S6AS5_NgNm27oo
00=g_@0C0180100B00D04@@X9BUcW7_N00aoo`<03@@0300700/@Q2DY?NmJeW>LNmh01Woo00=kgW>L
00L00`0700@01P@Y=JeJeR1oo`0037oo<f`700ADjgooOomooaM/1h5oo`0301L05P0F00D05P046<I6
<FmkMkd4Ool01G_NMkecW6mkIcT00P0C1@0B00@49b48HaQ[FP=_N`03Liag_Goo00Eoo`04Nmh03@0=
00d400`200/01RU:=Je6<EkgLiag_@Eoo`03Mke_N`0700<01`0400I245:DKg/POol000aooc=/1`04
E>]oogooOolGK0MlOol00g_NKg]W>@02F]H601L201H011cWAS5_NgNm0goo00IkgV<HE[De[BU:8@P4
01<301800`0636<Q20039BT02RU:<Ha>LgNmOomg_F]JG_MJeUJe100=100<00PHb`0;=K=6<Cg_AS5:
DVLi0fmk00=S65:D12X00`0700@YCekgLiakgR5oo`0037oo<f`700ADjgooOomooaM/1gaoo`05LiaN
mdic?Nle[@0701L01@0F8@Q:DVmkNmh00goo00=>N`0D01@00`0D100C1@0B0`0A0P0@00Le[E:DMkek
gVmkDY@mk`02=Jd400d400`03Be[6=002acaCW=243g_BU9>Le:DCW=240@Z0080200400LaTF<HLi`S
Ool000aooaU/1`03L8]oogoo039/1gaoo`05BU/mmc6E:E8U<@0201P601L0136<E[EcW7_N0goo00=>
O00E01D0100D100C100B100A00<045JeIcT00W_N00I6>3Fd:E0U;b4?00h400d300`01cg_G_L]M@0;
00Y>MDic008mk`8icP0724`0200800Q>MF]JMkd097oo000<OolIK0L00g2;Oomoo`0bK0MlOol801P5
01L0148@G_Mg_G_N0goo00=BW00E01D0100D100C100B100A00D046LiLiaoog_N00<03`<03P@03@<0
300<BU9W>GNm24h02`0:9C9:DT8@?Nl@S@090P0800<aTV]JMkd09Goo000<OolIK0L00g2;Oomoo`0b
K0MlOol:01P301L00fLiLiakgP07Ool2Nmh00g>L01@04`0401<01@0B12PU:FmkMkd017_N0goo0`0?
0`0>100=0`0<00E[FWNmOomoofmm00<02P@02@0448he]7NmNmhVOol000aooaU/1`03L8]oogoo039/
1gmoo`]kgP]oo`03Mkd0500D00D04`0412PYBW>LNmh:Ool;Nmh6Ool015kkCWUg_GNm0g_N:7oo000<
OolIK0L00g2;Oomoo`0bK0NEOol00gNm01@0500501<010@X:DYg_G_NBWoo000<OolIK0L00g2;Oomo
o`0bK0NEOol017Nm01@0500D100C00@4:2U:MkekgTYoo`0037oo6F`700=`RgooOol0<V`7UGoo00=k
gP0E01@00`0D0P0C00@8BBU:MkekgTYoo`0037oo6F`700=`RgooOol0<V`7UGoo00=kgP0E01@00`0D
0P0C00@@RcF]MkekgTYoo`0037oo6F`700=`RgooOol0<V`7Q7oo0W_N0WNm00=kgWooOol02goo00<0
5@0D01@00P0D0P0C00<U<DicNmh0Bgoo000<OolIK0L00g2;Oomoo`0bK0N3Ool01W_NLia_Nf]JKg]c
W0eoo`0301D0500D00<0500401<e]5kgNmi;Ool000aooaU/1`03L8]oogoo039/1h9oo`04MkeW>EJe
CW<2AS400e:DMkeoo`0<Ool00dikBU]:F`028AL00`0CBUYg_@1<Ool000aooaU/1`03L8]oogoo039/
1h5oo`0:NmiW>DYB;F/U:AS67>LYBV<HMkePOol000aooaU/1`03L8]oogoo039/1h5oo`03Kg]6=00I
00<06@0512H<HdHaJeYkgP1OOol003Aoo`03E>]/1f`701I/1`03D4Moogoo08]oo`03F]P06@0I00@0
6@0400/aS5kgMkeOOol003Aoo`03E>]/1f`701I/1`03D4Moogoo08]oo`P06@04:DYF]GNmNmiNOol0
03Aoo`03E>]/1f`701I/1`03D4Moogoo08]oo`P06@03>LiS67Nm05moo`00=7oo00=Djf`7K0L05V`7
00=@AgooOol0Rgoo200I00=>LfmkNmh0Ggoo000dOol00eC[K0M/1`0FK0L00e17Oomoo`2;Ool801T0
0ekgLiaoo`1OOol003Aoo`03E>]/1f`701I/1`03D4Moogoo08]oo`03DYd06@0I00@06@036=McW7oo
061oo`00=7oo00=Djf`7K0L05V`700=@AgooOol0S7oo00=No@0I01T00P0I00=26G>LOol0HGoo000d
Ool00eC[K0M/1`0FK0L00e17Oomoo`2@Ool2NmiSOol003Aoo`03E>]/1f`701I/1`03D4Moogoo0?Eo
o`00=7oo00=Djf`7K0L05V`700=@AgooOol0mGoo000dOol00eC[K0M/1`0FK0L00e17Oomoo`3eOol0
03Aoo`03E>]/1f`701I/1`03D4Moogoo0?Eoo`00ogooAWoo003oOom6Ool00?moodIoo`00\
\>"],
        ImageRangeCache->{{{0, 324}, {77.6875, 0}} -> {0, 0, 0, 0}, {{9.3125, 
        131.438}, {75.8125, 1.8125}} -> {-10, -3, 0, 0}, {{192.5, 314.625}, {
        75.8125, 1.8125}} -> {-237, -4, 1, 1}}],
      TextAlignment->Right], "\[IndentingNewLine]", 
    StyleBox[
      RowBox[{
        ButtonBox[\(Graz\ University\ of\ Technology\),
          ButtonData:>{
            URL[ "http://www.tu-graz.ac.at"], None},
          ButtonStyle->"Hyperlink"], 
        ButtonBox[\(Institute\ of\ Theoretical\ Physics\),
          ButtonData:>{
            URL[ "http://www.itp.tu-graz.ac.at"], None},
          ButtonStyle->"Hyperlink"]}],
      FontFamily->"Arial",
      FontSize->14,
      FontWeight->"Plain",
      Background->None,
      FontVariations->{"CompatibilityType"->0}]}], "Input",
  TextAlignment->Right]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Headings", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Title"],
  ShowCellBracket->False,
  CellMargins->{{60, 0}, {0, 5}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{0.95, 11},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Arial",
  FontSize->36,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontTracking->"Plain",
  FontColor->RGBColor[0.740001, 0.0200046, 0.270008]],

Cell[StyleData["Title", "Printout"],
  CellMargins->{{9, 0}, {0, 0}},
  FontSize->24,
  FontTracking->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subtitle"],
  ShowCellBracket->False,
  CellMargins->{{60, 0}, {0, 5}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 0},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Arial",
  FontSize->14,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.740001, 0.0200046, 0.270008]],

Cell[StyleData["Subtitle", "Printout"],
  CellMargins->{{9, 0}, {0, 0}},
  ParagraphIndent->-85]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsubtitle"],
  ShowCellBracket->False,
  CellMargins->{{60, 4}, {30, 10}},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
  FontFamily->"Arial",
  FontSize->12,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.740001, 0.0200046, 0.270008]],

Cell[StyleData["Subsubtitle", "Printout"],
  CellMargins->{{9, 10}, {50, 10}},
  FontSize->14]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Section"],
  CellFrame->{{6, 0}, {0, 1}},
  CellDingbat->None,
  CellMargins->{{44, 0}, {10, 35}},
  CellGroupingRules->{"SectionGrouping", 30},
  PageBreakBelow->False,
  CellFrameMargins->{{8, 4}, {0, 4}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{0.95, 9},
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
  FontFamily->"Arial",
  FontSize->20,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.740001, 0.0200046, 0.270008]],

Cell[StyleData["Section", "Printout"],
  CellMargins->{{9, 0}, {2, 50}},
  CellFrameMargins->{{5, 4}, {0, 4}},
  FontSize->14,
  FontTracking->"Plain"]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{60, 0}, {8, 10}},
  CellGroupingRules->{"SectionGrouping", 40},
  PageBreakBelow->False,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 7},
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}},
  FontFamily->"Arial",
  FontSize->18,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.740001, 0.0200046, 0.270008]],

Cell[StyleData["Subsection", "Printout"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{9, 0}, {6, 40}},
  FontSize->12]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Subsubsection"],
  CellDingbat->"\[FilledSquare]",
  CellMargins->{{60, Inherited}, {8, 12}},
  CellGroupingRules->{"SectionGrouping", 50},
  PageBreakBelow->False,
  CellFrameLabelMargins->6,
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, BoxBaselineShift -> 
              0.5], "X"}]], "mma"->"Mathematica", "Mma"->"Mathematica", 
      "MMA"->"Mathematica", Inherited},
  LineSpacing->{1, 7},
  CounterIncrements->"Subsubsection",
  FontFamily->"Arial",
  FontSize->13,
  FontWeight->"Bold",
  FontSlant->"Italic",
  FontColor->RGBColor[0.740001, 0.0200046, 0.270008]],

Cell[StyleData["Subsubsection", "Printout"],
  CellMargins->{{22, 0}, {4, 20}},
  FontSize->11]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Body Text", "Section"],

Cell[CellGroupData[{

Cell[StyleData["Text"],
  CellMargins->{{60, 20}, {10, 5}},
  InputAutoReplacements->{"TeX"->StyleBox[ 
          RowBox[ {"T", 
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
              BoxBaselineShift -> 0.5], "X"}]], "LaTeX"->StyleBox[ 
          RowBox[ {"L", 
            StyleBox[ 
              AdjustmentBox[ 
              "A", BoxMargins -> {{-0.36, -0.1}, {0, -0}}, 
                BoxBaselineShift -> -0.2], FontSize -> Smaller], "T", 
            
            AdjustmentBox[ 
            "E", BoxMargins -> {{-0.075, -0.085}, {0, 0}}, 
              BoxBaselineShift -> 0.5], "X"}]], "mma"->"Mathematica", 
      "Mma"->"Mathematica", "MMA"->"Mathematica", Inherited},
  Hyphenation->True,
  LineSpacing->{1, 0},
  ParagraphSpacing->{0, 12},
  FontFamily->"Times"],

Cell[StyleData["Text", "Printout"],
  CellMargins->{{9, 0}, {4, 4}},
  ParagraphSpacing->{0, 6}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Commentary"],
  CellMargins->{{60, 20}, {2, 8}},
  PageBreakBelow->False,
  TextJustification->1,
  Hyphenation->True,
  LineSpacing->{1, 2},
  FontFamily->"Helvetica",
  FontSize->10,
  FontColor->RGBColor[0, 0, 0.4]],

Cell[StyleData["Commentary", "Printout"],
  CellMargins->{{9, 0}, {4, 4}},
  LineSpacing->{1, 3},
  FontSize->8]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["Author"],
  ShowCellBracket->False,
  CellMargins->{{60, 4}, {30, 10}},
  PageBreakBelow->False,
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {
      "Figure", 0}},
  FontFamily->"Helvetica",
  FontSize->12,
  FontSlant->"Italic"],

Cell[StyleData["Author", "Printout"],
  CellMargins->{{9, 10}, {50, 10}},
  FontSize->14]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Styles for Input/Output", "Section"],

Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["InputToEdit"],
  CellFrame->True,
  CellMargins->{{60, 20}, {6, 6}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.6, 0.2, 0],
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  Background->RGBColor[0.996109, 0.699229, 0.398444]],

Cell[StyleData["InputToEdit", "Printout"],
  CellFrame->{{3, 1}, {1, 1}},
  CellMargins->{{37, 0}, {6, 6}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  Background->GrayLevel[0.949996]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Input"],
  CellFrame->{{3, 0}, {0, 0}},
  CellMargins->{{60, 20}, {6, 6}},
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0.6, 0.2, 0],
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  LinebreakAdjustments->{0.85, 2, 10, 0, 1},
  CounterIncrements->"Input",
  FontFamily->"Times New Roman",
  FontWeight->"Bold",
  Background->RGBColor[0.996109, 0.898451, 0.898451]],

Cell[StyleData["Input", "Printout"],
  CellFrame->{{3, 0}, {0, 0}},
  CellMargins->{{37, 0}, {6, 6}},
  LinebreakAdjustments->{0.85, 2, 10, 1, 1},
  Background->GrayLevel[0.949996]]
}, Open  ]],

Cell[StyleData["InlineInput"],
  Evaluatable->True,
  CellGroupingRules->"InputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  DefaultFormatType->DefaultInputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  FormatType->InputForm,
  ShowStringCharacters->True,
  NumberMarks->True,
  CounterIncrements->"Input",
  FontFamily->"Times New Roman",
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[StyleData["Output"],
  CellMargins->{{60, 20}, {15, 0}},
  CellEditDuplicate->True,
  CellGroupingRules->"OutputGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  CellFrameColor->RGBColor[0, 0.500008, 0.6],
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  AutoItalicWords->{},
  LanguageCategory->"Formula",
  FormatType->InputForm,
  CounterIncrements->"Output",
  FontFamily->"Times New Roman",
  Background->RGBColor[0.996109, 0.898451, 0.898451]],

Cell[StyleData["Output", "Printout"],
  CellFrame->False,
  CellMargins->{{37, 0}, {6, 2}},
  Background->GrayLevel[0.949996]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Graphics"],
  CellMargins->{{60, 20}, {0, 0}},
  CellGroupingRules->"GraphicsGrouping",
  CellHorizontalScrolling->True,
  PageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellFrameColor->RGBColor[0, 0.6, 0.6],
  DefaultFormatType->DefaultOutputFormatType,
  FormatType->InputForm,
  CounterIncrements->"Graphics",
  ImageSize->{250, 250},
  FontFamily->"Times New Roman",
  Background->None],

Cell[StyleData["Graphics", "Printout"],
  CellFrame->False,
  CellMargins->{{37, 0}, {6, 2}},
  ImageSize->{250, 250},
  ImageMargins->{{28, Inherited}, {Inherited, 0}},
  Background->None]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["Message"],
  CellMargins->{{72, 20}, {Inherited, Inherited}},
  CellGroupingRules->"OutputGrouping",
  PageBreakWithin->False,
  GroupPageBreakWithin->False,
  GeneratedCell->True,
  CellAutoOverwrite->True,
  ShowCellLabel->False,
  CellLabelMargins->{{23, Inherited}, {Inherited, Inherited}},
  DefaultFormatType->DefaultOutputFormatType,
  HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
  FormatType->InputForm,
  StyleMenuListing->None,
  FontFamily->"Times New Roman",
  FontColor->GrayLevel[0]],

Cell[StyleData["Message", "Printout"],
  CellMargins->{{44, Inherited}, {Inherited, Inherited}},
  FontColor->GrayLevel[0]]
}, Open  ]],

Cell[CellGroupData[{

Cell[StyleData["CellLabel"],
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontTracking->"Extended",
  FontColor->RGBColor[0.571389, 0.19675, 0.570504]],

Cell[StyleData["CellLabel", "Printout"],
  FontFamily->"Courier",
  FontSize->8,
  FontSlant->"Italic",
  FontColor->GrayLevel[0]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Unique Styles", "Section"],

Cell[CellGroupData[{

Cell[StyleData["DisplayText"],
  CellFrame->0.5,
  CellMargins->{{60, 20}, {15, 5}},
  LineSpacing->{0, 12},
  ParagraphSpacing->{0, 6},
  FontFamily->"Helvetica",
  FontSize->12,
  FontWeight->"Bold",
  FontSlant->"Plain",
  Background->RGBColor[1, 1, 0.8]],

Cell[StyleData["DisplayText", "Printout"],
  CellFrame->3,
  CellMargins->{{9, 0}, {4, 4}},
  ParagraphSpacing->{0, 6},
  FontSize->10,
  Background->GrayLevel[0.949996]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Styles for Headers and Footers", "Section"],

Cell[StyleData["Header"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontSlant->"Italic"],

Cell[StyleData["Footer"],
  CellMargins->{{0, 0}, {0, 4}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->6],

Cell[StyleData["PageNumber"],
  CellMargins->{{0, 0}, {4, 1}},
  StyleMenuListing->None,
  FontFamily->"Helvetica",
  FontSize->9,
  FontWeight->"Bold"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hyperlink Styles", "Section"],

Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same \
Notebook, or between Notebooks.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Hyperlink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookLocate[ #2]}]&),
  Active->True,
  ButtonNote->ButtonData}],

Cell[StyleData["Hyperlink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell["\<\
The following styles are for linking automatically to the \
on-line help system.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["MainBookLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["MainBookLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["AddOnsLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["AddOnLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["RefGuideLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontFamily->"Courier",
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["RefGuideLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["GettingStartedLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["GettingStartedLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["OtherInformationLink"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  FontColor->RGBColor[0, 0, 1],
  FontVariations->{"Underline"->True},
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
  Active->True,
  ButtonFrame->"None"}],

Cell[StyleData["OtherInformationLink", "Printout"],
  FontColor->GrayLevel[0],
  FontVariations->{"Underline"->False}]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Palette Styles", "Section"],

Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],

Cell[StyleData["Paste"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, After]}]&)}],

Cell[StyleData["Evaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["EvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionMove[ 
        FrontEnd`InputNotebook[ ], All, Cell, 1], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluate"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluate[ 
        FrontEnd`InputNotebook[ ], All]}]&)}],

Cell[StyleData["CopyEvaluateCell"],
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic,
  ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
      FrontEnd`SelectionCreateCell[ 
        FrontEnd`InputNotebook[ ], All], 
      FrontEnd`NotebookApply[ 
        FrontEnd`InputNotebook[ ], #, All], 
      FrontEnd`SelectionEvaluateCreateCell[ 
        FrontEnd`InputNotebook[ ], All]}]&)}]
}, Closed]],

Cell[CellGroupData[{

Cell["Placeholder Styles", "Section"],

Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],

Cell[CellGroupData[{

Cell[StyleData["Placeholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->True,
  StyleMenuListing->None],

Cell[StyleData["Placeholder", "Presentation"]],

Cell[StyleData["Placeholder", "Condensed"]],

Cell[StyleData["Placeholder", "Printout"]]
}, Closed]],

Cell[CellGroupData[{

Cell[StyleData["SelectionPlaceholder"],
  Editable->False,
  Selectable->False,
  StyleBoxAutoDelete->True,
  Placeholder->PrimaryPlaceholder,
  StyleMenuListing->None,
  DrawHighlighted->True],

Cell[StyleData["SelectionPlaceholder", "Presentation"]],

Cell[StyleData["SelectionPlaceholder", "Condensed"]],

Cell[StyleData["SelectionPlaceholder", "Printout"]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["FormatType Styles", "Section"],

Cell["\<\
The cells below define styles that are mixed in with the \
styles of most cells.  If a cell's FormatType matches the name of one \
of the styles defined below, then that style is applied between the \
cell's style and its own options.\
\>", "Text"],

Cell[StyleData["CellExpression"],
  PageWidth->Infinity,
  CellMargins->{{6, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  ShowSpecialCharacters->False,
  AllowInlineCells->False,
  AutoItalicWords->{},
  StyleMenuListing->None,
  FontFamily->"Courier",
  FontSize->12,
  Background->GrayLevel[1]],

Cell[StyleData["InputForm"],
  InputAutoReplacements->{},
  AllowInlineCells->False,
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["OutputForm"],
  PageWidth->Infinity,
  TextAlignment->Left,
  LineSpacing->{1, -5},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["StandardForm"],
  InputAutoReplacements->{
    "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
      ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
      Inherited},
  LineSpacing->{1.25, 0},
  StyleMenuListing->None,
  FontFamily->"Courier"],

Cell[StyleData["TraditionalForm"],
  InputAutoReplacements->{
    "->"->"\[Rule]", ":>"->"\[RuleDelayed]", "<="->"\[LessEqual]", 
      ">="->"\[GreaterEqual]", "!="->"\[NotEqual]", "=="->"\[Equal]", 
      Inherited},
  LineSpacing->{1.25, 0},
  SingleLetterItalics->True,
  TraditionalFunctionNotation->True,
  DelimiterMatching->None,
  StyleMenuListing->None],

Cell["\<\
The style defined below is mixed in to any cell that is in \
an inline cell within another.\
\>", "Text"],

Cell[StyleData["InlineCell"],
  TextAlignment->Left,
  ScriptLevel->1,
  StyleMenuListing->None],

Cell[StyleData["InlineCellEditing"],
  StyleMenuListing->None,
  Background->RGBColor[1, 0.749996, 0.8]]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1152}, {0, 850}},
WindowSize->{688, 768},
WindowMargins->{{Automatic, 205}, {Automatic, 25}},
MacintoshSystemPageSetup->"\<\
00<0001804P000000`d26_oRon<3;08f0dL5N`?P0080001804P000000`d26P01
0000I00000400`<30?l00BL?00400@00000000000000060801T1T00000000000
00000000004000000000000000000000\>"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 37, 0, 61, "Subtitle"],
Cell[1767, 54, 193, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[1985, 62, 42, 0, 56, "Section"],
Cell[2030, 64, 77, 2, 70, 31, 0, "StyleData", "All", "Working"],
Cell[2110, 68, 140, 4, 70, 32, 0, "StyleData", "All", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[2287, 77, 35, 0, 36, "Section"],
Cell[2325, 79, 101, 3, 70, "Text"],
Cell[2429, 84, 560, 14, 70, 27, 0, "StyleData", "Notebook", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[3026, 103, 51, 0, 36, "Section"],

Cell[CellGroupData[{
Cell[3102, 107, 226, 7, 28, 29, 0, "StyleData", "HeaderCell", "All"],
Cell[3331, 116, 100153, 1538, 137, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[103533, 1660, 38, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[103596, 1664, 1026, 25, 62, 24, 0, "StyleData", "Title", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[104625, 1691, 110, 3, 43, 36, 0, "StyleData", "Title", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[104772, 1699, 1000, 24, 37, 27, 0, "StyleData", "Subtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[105775, 1725, 96, 2, 32, 39, 0, "StyleData", "Subtitle", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105908, 1732, 982, 23, 70, 30, 0, "StyleData", "Subsubtitle", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[106893, 1757, 94, 2, 92, 42, 0, "StyleData", "Subsubtitle", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107024, 1764, 1139, 28, 88, 26, 0, "StyleData", "Section", "All",
  CounterIncrements->"Section",
  CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}}],
Cell[108166, 1794, 151, 4, 89, 38, 0, "StyleData", "Section", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[108354, 1803, 1066, 26, 54, 29, 0, "StyleData", "Subsection", "All",
  CounterIncrements->"Subsection",
  CounterAssignments->{{"Subsubsection", 0}}],
Cell[109423, 1831, 125, 3, 76, 41, 0, "StyleData", "Subsection", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109585, 1839, 1062, 26, 51, 32, 0, "StyleData", "Subsubsection", "All",
  CounterIncrements->"Subsubsection"],
Cell[110650, 1867, 95, 2, 52, 44, 0, "StyleData", "Subsubsection", \
"Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[110794, 1875, 39, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[110858, 1879, 823, 20, 43, 23, 0, "StyleData", "Text", "All"],
Cell[111684, 1901, 96, 2, 70, 35, 0, "StyleData", "Text", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[111817, 1908, 234, 8, 33, 29, 0, "StyleData", "Commentary", "All"],
Cell[112054, 1918, 112, 3, 70, 41, 0, "StyleData", "Commentary", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[112203, 1926, 257, 8, 64, 25, 0, "StyleData", "Author", "All",
  CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}}],
Cell[112463, 1936, 89, 2, 70, 37, 0, "StyleData", "Author", "Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[112601, 1944, 42, 0, 36, "Section"],
Cell[112646, 1946, 248, 5, 46, "Text"],

Cell[CellGroupData[{
Cell[112919, 1955, 763, 21, 58, 30, 0, "StyleData", "InputToEdit", "All",
  CounterIncrements->"Input"],
Cell[113685, 1978, 187, 4, 60, 42, 0, "StyleData", "InputToEdit", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113909, 1987, 769, 21, 58, 24, 0, "StyleData", "Input", "All",
  CounterIncrements->"Input"],
Cell[114681, 2010, 181, 4, 58, 36, 0, "StyleData", "Input", "Printout"]
}, Open  ]],
Cell[114877, 2017, 475, 14, 38, 30, 0, "StyleData", "InlineInput", "All",
  CounterIncrements->"Input"],

Cell[CellGroupData[{
Cell[115377, 2035, 686, 18, 61, 25, 0, "StyleData", "Output", "All",
  CounterIncrements->"Output"],
Cell[116066, 2055, 126, 3, 54, 37, 0, "StyleData", "Output", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116229, 2063, 459, 14, 30, 27, 0, "StyleData", "Graphics", "All",
  CounterIncrements->"Graphics"],
Cell[116691, 2079, 189, 5, 38, 39, 0, "StyleData", "Graphics", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116917, 2089, 534, 14, 38, 26, 0, "StyleData", "Message", "All",
  StyleMenuListing->None],
Cell[117454, 2105, 123, 2, 38, 38, 0, "StyleData", "Message", "Printout"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117614, 2112, 222, 7, 34, 28, 0, "StyleData", "CellLabel", "All",
  StyleMenuListing->None],
Cell[117839, 2121, 130, 4, 70, 40, 0, "StyleData", "CellLabel", "Printout"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[118018, 2131, 32, 0, 56, "Section"],

Cell[CellGroupData[{
Cell[118075, 2135, 258, 9, 67, 30, 0, "StyleData", "DisplayText", "All"],
Cell[118336, 2146, 170, 5, 57, 42, 0, "StyleData", "DisplayText", "Printout"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[118555, 2157, 49, 0, 56, "Section"],
Cell[118607, 2159, 149, 5, 31, 25, 0, "StyleData", "Header", "All",
  StyleMenuListing->None],
Cell[118759, 2166, 126, 4, 26, 25, 0, "StyleData", "Footer", "All",
  StyleMenuListing->None],
Cell[118888, 2172, 152, 5, 32, 29, 0, "StyleData", "PageNumber", "All",
  StyleMenuListing->None]
}, Closed]],

Cell[CellGroupData[{
Cell[119077, 2182, 35, 0, 36, "Section"],
Cell[119115, 2184, 184, 4, 46, "Text"],

Cell[CellGroupData[{
Cell[119324, 2192, 302, 8, 36, 28, 0, "StyleData", "Hyperlink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[119629, 2202, 107, 2, 40, 40, 0, "StyleData", "Hyperlink", "Printout"]
}, Closed]],
Cell[119751, 2207, 104, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[119880, 2214, 316, 8, 36, 31, 0, "StyleData", "MainBookLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[120199, 2224, 110, 2, 40, 43, 0, "StyleData", "MainBookLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[120346, 2231, 337, 9, 36, 29, 0, "StyleData", "AddOnsLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[120686, 2242, 107, 2, 40, 40, 0, "StyleData", "AddOnLink", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[120830, 2249, 345, 9, 36, 31, 0, "StyleData", "RefGuideLink", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[121178, 2260, 110, 2, 40, 43, 0, "StyleData", "RefGuideLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[121325, 2267, 328, 8, 36, 37, 0, "StyleData", "GettingStartedLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[121656, 2277, 116, 2, 40, 49, 0, "StyleData", "GettingStartedLink", \
"Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[121809, 2284, 332, 8, 36, 39, 0, "StyleData", "OtherInformationLink", \
"All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[122144, 2294, 118, 2, 40, 51, 0, "StyleData", "OtherInformationLink", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[122311, 2302, 33, 0, 36, "Section"],
Cell[122347, 2304, 121, 3, 30, "Text"],
Cell[122471, 2309, 226, 5, 36, 24, 0, "StyleData", "Paste", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[122700, 2316, 295, 7, 36, 27, 0, "StyleData", "Evaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[122998, 2325, 400, 9, 36, 31, 0, "StyleData", "EvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[123401, 2336, 387, 9, 36, 31, 0, "StyleData", "CopyEvaluate", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic],
Cell[123791, 2347, 401, 9, 36, 35, 0, "StyleData", "CopyEvaluateCell", "All",
  StyleMenuListing->None,
  ButtonStyleMenuListing->Automatic]
}, Closed]],

Cell[CellGroupData[{
Cell[124229, 2361, 37, 0, 36, "Section"],
Cell[124269, 2363, 115, 3, 30, "Text"],

Cell[CellGroupData[{
Cell[124409, 2370, 145, 5, 36, 30, 0, "StyleData", "Placeholder", "All",
  StyleMenuListing->None],
Cell[124557, 2377, 46, 0, 70, 46, 0, "StyleData", "Placeholder", \
"Presentation"],
Cell[124606, 2379, 43, 0, 70, 43, 0, "StyleData", "Placeholder", \
"Condensed"],
Cell[124652, 2381, 42, 0, 70, 42, 0, "StyleData", "Placeholder", "Printout"]
}, Closed]],

Cell[CellGroupData[{
Cell[124731, 2386, 193, 6, 36, 39, 0, "StyleData", "SelectionPlaceholder", \
"All",
  StyleMenuListing->None],
Cell[124927, 2394, 55, 0, 70, 55, 0, "StyleData", "SelectionPlaceholder", \
"Presentation"],
Cell[124985, 2396, 52, 0, 70, 52, 0, "StyleData", "SelectionPlaceholder", \
"Condensed"],
Cell[125040, 2398, 51, 0, 70, 51, 0, "StyleData", "SelectionPlaceholder", \
"Printout"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[125140, 2404, 36, 0, 36, "Section"],
Cell[125179, 2406, 258, 5, 62, "Text"],
Cell[125440, 2413, 314, 10, 36, 33, 0, "StyleData", "CellExpression", "All",
  StyleMenuListing->None],
Cell[125757, 2425, 135, 4, 36, 28, 0, "StyleData", "InputForm", "All",
  StyleMenuListing->None],
Cell[125895, 2431, 150, 5, 41, 29, 0, "StyleData", "OutputForm", "All",
  StyleMenuListing->None],
Cell[126048, 2438, 292, 7, 36, 31, 0, "StyleData", "StandardForm", "All",
  StyleMenuListing->None],
Cell[126343, 2447, 363, 9, 36, 34, 0, "StyleData", "TraditionalForm", "All",
  StyleMenuListing->None],
Cell[126709, 2458, 115, 3, 30, "Text"],
Cell[126827, 2463, 96, 3, 36, 29, 0, "StyleData", "InlineCell", "All",
  StyleMenuListing->None],
Cell[126926, 2468, 104, 2, 52, 36, 0, "StyleData", "InlineCellEditing", "All",
  
  StyleMenuListing->None]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

