(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     37016,       1000]*)
(*NotebookOutlinePosition[     38037,       1032]*)
(*  CellTagsIndexPosition[     37993,       1028]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Free Fall", "Title",
  CellFrame->{{0, 0}, {3, 0}},
  TextAlignment->Center,
  TextJustification->0,
  FontFamily->"Albertus Extra Bold CE"],

Cell[CellGroupData[{

Cell["\<\
Parameters
\
\>", "Section",
  FormatType->TextForm],

Cell[CellGroupData[{

Cell["\<\
Approximate Solution:
\
\>", "Subsection"],

Cell[TextData[{
  "\nSize of discrete Hamilton-matrix ",
  StyleBox["nd ",
    FontWeight->"Bold"],
  "and maximal height to be included in the discrete Matrix ",
  StyleBox["xmaxd",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(nd = 100; xmaxd = 10. ;\)\)\)], "Input"],

Cell["\<\

Lowering nd increases discretization error and speed. Too small a value for \
xmaxd gives false eigenvalues and eigenfunctions; very large xmaxd cuse \
uninteresting regions to be included in calculation.\
\>", "Text",
  FormatType->TextForm]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Dynamics
\
\>", "Subsection"],

Cell[TextData[{
  "\n",
  StyleBox["Center",
    FontWeight->"Bold"],
  " x0 and ",
  StyleBox["width",
    FontWeight->"Bold"],
  " ",
  "\[Sigma]0 ",
  "of initial gaussian wave packet:"
}], "Text"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(x0 = 7; \[Sigma]0 = 0.5;\)\)\)], "Input"],

Cell["\<\

This shoul be well below xmaxd!\
\>", "Text",
  FormatType->TextForm],

Cell[TextData[{
  "\n",
  StyleBox["Number of periods",
    FontWeight->"Bold"],
  " Nper for which the evaluation is to be calculated,  ",
  StyleBox["Number of timesteps",
    FontWeight->"Bold"],
  " Nt0 per period, ",
  StyleBox["Number of eigenstates",
    FontWeight->"Bold"],
  " Mmaxe included in spectral theorem: "
}], "Text"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(Nper = 2; Nt0 = 50;\)\)\)], "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Explanation", "Section",
  CellFrame->{{0, 0}, {2, 0}}],

Cell[TextData[{
  StyleBox["Hamilton-Function of a particle in the gravitational potential", 
    "Text",
    CellFrame->True,
    FontFamily->"Albertus Extra Bold CE"],
  StyleBox["\n\n", "Text",
    Background->RGBColor[1, 1, 0]],
  Cell[BoxData[
      \(TraditionalForm\`\(H\  = p\^2\/\(2\ m\)\ \  + \ \ m\ g\ x\ ;\)\)],
    FontColor->GrayLevel[0]],
  "    ",
  StyleBox["  ",
    FontColor->GrayLevel[0]],
  StyleBox["(V(x) = \[Infinity] for x \[LessEqual]  0)",
    FontWeight->"Bold",
    FontColor->GrayLevel[0]],
  StyleBox["\n\n", "Input",
    FontFamily->"Terminal",
    FontSize->17,
    FontWeight->"Plain",
    Background->RGBColor[1, 1, 0],
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["Schr\[ODoubleDot]dinger-Equation ", "Text",
    CellFrame->True,
    FontFamily->"Albertus Extra Bold CE"],
  StyleBox["\n\n", "Text",
    Background->RGBColor[1, 1, 0]],
  Cell[BoxData[
      \(TraditionalForm\`\(-\(h\&~\^2\/\(2\ m\)\)\)\ d\^2\/dx\^2\)],
    FontColor->GrayLevel[0]],
  StyleBox[" \[CapitalPsi](x)  +  m g x \[CapitalPsi](x)  =  E \
\[CapitalPsi](x) ;  ",
    FontColor->GrayLevel[0]],
  StyleBox[" for x \[GreaterEqual] 0\n",
    FontWeight->"Bold",
    FontColor->GrayLevel[0]],
  StyleBox["\[CapitalPsi](x) = 0;  for x \[LessEqual]  0   (*)",
    FontColor->GrayLevel[0],
    FontVariations->{"CompatibilityType"->0}],
  StyleBox["\n", "Text",
    Background->RGBColor[1, 1, 0]],
  StyleBox["\nd", "Text",
    CellFrame->True],
  StyleBox["imensionsless quantities\n", "Text",
    CellFrame->True,
    FontFamily->"Albertus Extra Bold CE"],
  StyleBox["\n", "Text",
    Background->RGBColor[1, 1, 0]],
  Cell[BoxData[{
      FormBox[\(x\ \ \ \ \ \  = \ \ \ \[Xi]\ \ \ x\_0\), TraditionalForm], 
    "\[IndentingNewLine]", 
      FormBox[
        RowBox[{\(x\_0\ \ \ \  = \ \((h\&~\^2\/\(2\ \(m\^2\) \
g\))\)\^\(1/3\)\), " "}], TraditionalForm], "\[IndentingNewLine]", 
      FormBox[\(E\ \ \ \ \ \  = \ \[Epsilon]\ E\_0\), TraditionalForm], 
    "\[IndentingNewLine]", 
      FormBox[
        RowBox[{\(E\_0\), "    ", "=", " ", 
          RowBox[{\(m\ g\ x\_0\), "  ", "=", " ", 
            
            RowBox[{\(\((\(m\ g\^2\ h\&~\^2\)\/\(\(2\)\(\ \)\))\)\^\(1/3\)\), 
              "  ", 
              StyleBox["\[DoubleRightArrow]",
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox[" ",
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox[Cell[TextData[Cell[BoxData[
                    FormBox[
                      RowBox[{\(x\_0\), ":", " ", 
                        RowBox[{
                        Cell[""], "classical", " ", "turning", " ", 
                          "point"}]}], TraditionalForm]]]]],
                FontColor->RGBColor[0, 0, 1]]}]}]}], TraditionalForm], 
    "\[IndentingNewLine]", 
      FormBox[\(\[CapitalPhi](\[Xi])\  = \ \[CapitalPsi](\[Xi]\ x\_0)\), 
        TraditionalForm]}],
    FontColor->GrayLevel[0]],
  StyleBox["\n", "Text",
    Background->RGBColor[1, 1, 0]],
  StyleBox["\n", "Text"],
  StyleBox["Schr\[ODoubleDot]dinger-Equation", "Text",
    CellFrame->True,
    FontFamily->"Albertus Extra Bold CE"],
  StyleBox["\n\n-", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]'' \((\[Xi])\) + \ \[Xi]\ \ \(\
\[CapitalPhi](\[Xi])\)\ \ \  = \ \ \ \[Epsilon]\ \ \ \(\[CapitalPhi](\[Xi])\)\
\)],
    FontColor->GrayLevel[0]],
  StyleBox[" ;",
    FontColor->GrayLevel[0]]
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  TextJustification->0,
  FontFamily->"Albertus Medium CE",
  FontSize->15,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.849989]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Approximate solution", "Section",
  CellFrame->{{0, 0}, {2, 0}}],

Cell[TextData[{
  "\n",
  StyleBox["Discretization\n\n",
    FontFamily->"Albertus Extra Bold CE"],
  Cell[BoxData[
      \(TraditionalForm\`\[Xi]\)],
    FontColor->GrayLevel[0]],
  StyleBox[" \[RightArrow] ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Xi]\_j\)\(\ \)\(:=\)\(\ \)\)\)],
    FontColor->GrayLevel[0]],
  StyleBox["j \[CapitalDelta];    j=1,2,..,n;  ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalDelta] = \[Xi]\_max\)],
    FontColor->GrayLevel[0]],
  StyleBox["/n\n\n\[CapitalPhi](\[Xi]) \[RightArrow] ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          FormBox["\[CapitalPhi]",
            "TraditionalForm"], "j"], TraditionalForm]],
    FontColor->GrayLevel[0]],
  StyleBox[" := ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi](\[Xi]\_j)\)],
    FontColor->GrayLevel[0]],
  StyleBox["\n\n- ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            
            FormBox[\(\[CapitalPhi]\_\(j - 1\)\  - \ 
                2  \[CapitalPhi]\_j\  + \ \[CapitalPhi]\_\(j + 1\)\),
              "TraditionalForm"], ")"}], "/", \(\[CapitalDelta]\^2\)}], 
        TraditionalForm]],
    FontColor->GrayLevel[0]],
  StyleBox["+ j \[CapitalDelta] ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\_j\ \  = \ \[Epsilon]\ \ \[CapitalPhi]\
\_j\)],
    FontColor->GrayLevel[0]],
  StyleBox["\n\n",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPhi]\_0 = \ \(\[CapitalPhi]\_n\  = \ 0\)\)],
    
    FontColor->GrayLevel[0]],
  "\n\n(due to (*)  and \[CapitalPhi](x) ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[LongRightArrow]\)\(\ \)\)\+\(x \[RightArrow] \
\[Infinity]\)\)]],
  "  0 )"
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  TextJustification->0,
  FontFamily->"Albertus Medium CE",
  FontSize->15,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.849989]],

Cell[CellGroupData[{

Cell["Definition", "Subsection",
  CellDingbat->"\[LightBulb]",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \(M[n_, xmax_] := 
      Block[{H, \[CapitalDelta], a}, \[CapitalDelta] = xmax/n; 
        a = 1/\[CapitalDelta]\^2; \[IndentingNewLine]\t\t\t\tH = 
          Table[If[i \[Equal] j, 2  a + \ i\ \[CapitalDelta], 
              If[Abs[i - j] \[Equal] 1, \(-a\), 0]], {i, 1, n}, {j, 1, 
              n}]\[IndentingNewLine]\t\t\t]\)], "Input"],

Cell[TextData[{
  StyleBox["Meaning of Parameters:",
    FontFamily->"Albertus Extra Bold CE",
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FontVariations->{"Underline"->True}],
  StyleBox["n:\t\tdimension of Hamilon-matrix\n",
    FontFamily->"Albertus Medium CE",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(TraditionalForm\`xmax\)]],
  StyleBox[":\tmaximal x-coordinate included in descretized region\n",
    FontFamily->"Albertus Medium CE",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  CellDingbat->"\[ClubSuit]",
  FontFamily->"Albertus Medium CE",
  FontSize->14,
  FontColor->RGBColor[0, 0, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Display Matrix", "Subsection",
  CellDingbat->"\[WatchIcon]"],

Cell[BoxData[
    \(M[10, 1. ] // MatrixForm\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Definition:",
  FontColor->RGBColor[1, 0, 0]]], "Subsection",
  CellDingbat->"\[LightBulb]",
  TextAlignment->AlignmentMarker,
  FontFamily->"Albertus Medium CE",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[{
    \(\(Eigen[n_, xmax_] := 
        Block[{x, 
            ew, \[CapitalDelta], \[CapitalPhi]}, \[IndentingNewLine]\t\t\t\t\t\
\[CapitalDelta] = xmax/n; \[IndentingNewLine]\t\t\t\t\teigsy = 
            Eigensystem[N[M[n, xmax], 16]]; \[IndentingNewLine]\t\t\t\t\tew = 
            eigsy[\([1]\)]; 
          ListPlot[ew, PlotStyle \[Rule] {Hue[1]}, 
            PlotLabel \[Rule] "\<Eigenvalues of Discrete Hamiltonmatrix\>"]; \
\[IndentingNewLine]\t\t\t\t\tPrint[\*"\"\<\!\(\[Lambda]\_1\) = \>\"", \
\[Lambda]\_1 = \ 
              N[ew[\([n]\)], 8], "\<  exakt: \>", \(-ExactEigenvalue[
                1]\)]; \[IndentingNewLine]\t\t\t\t\t\
Print[\*"\"\<\!\(\[Lambda]\_2\) = \>\"", \[Lambda]\_2 = \ 
              N[ew[\([n - 1]\)], 8], "\<  exakt: \>", \(-ExactEigenvalue[
                2]\)]; \[IndentingNewLine]\t\t\t\t\t\
Print[\*"\"\<\!\(\[Lambda]\_3\) = \>\"", \[Lambda]\_3 = \ 
              N[ew[\([n - 2]\)], 8], "\<  exakt: \>", \(-ExactEigenvalue[
                3]\)]; \[IndentingNewLine]\t\t\t\t\tx\  = \ 
            Table[i\ \[CapitalDelta], {i, 1, 
                n}]; \[IndentingNewLine]\t\t\t\t\t\[CapitalPhi]\  = \ 
            eigsy[\([2, n]\)]; \ \ \ \ \ \ \[Xi]\_1\  = \ 
            x . Abs[\[CapitalPhi]]^2/\((Abs[\[CapitalPhi]]\  . 
                  Abs[\[CapitalPhi]])\); \[IndentingNewLine]\t\t\t\t\t\
\[CapitalPhi]\  = \ eigsy[\([2, n - 1]\)]; \[Xi]\_2\  = \ 
            x . Abs[\[CapitalPhi]]^2/\((Abs[\[CapitalPhi]]\  . 
                  Abs[\[CapitalPhi]])\); \ \ \[IndentingNewLine]\t\t\t\t\t\
\[CapitalPhi]\  = \ eigsy[\([2, n - 2]\)]; \[Xi]\_3\  = \ 
            x . Abs[\[CapitalPhi]]^2/\((Abs[\[CapitalPhi]]\  . 
                  Abs[\[CapitalPhi]])\); \ \ \[IndentingNewLine]\t\t\t\t\t\
Print[\*"\"\<\!\(\[Xi]\_1\) = \>\"", \[Xi]\_1, "\<  exakt: \>", 
            ExactMean[
              1]]; \[IndentingNewLine]\t\t\t\t\tPrint[\*"\"\<\!\(\[Xi]\_2\) = \
\>\"", \[Xi]\_2, "\<  exakt: \>", 
            ExactMean[
              2]]; \[IndentingNewLine]\t\t\t\t\tPrint[\*"\"\<\!\(\[Xi]\_3\) = \
\>\"", \[Xi]\_3, "\<  exakt: \>", 
            ExactMean[3]];\[IndentingNewLine]\t\t\t\t\t];\)\), "\n", 
    \(\(\[CapitalPsi][n_, xmax_, m_] := 
        Block[{x, \[CapitalDelta]}, \[CapitalDelta] = xmax/n; 
          x = Table[i\ \[CapitalDelta], {i, 1, n}]; 
          t = \(Eigensystem[N[M[n, xmax]]]\)[\([2]\)]; 
          p1 = ListPlot[Transpose[{x, t[\([m]\)]\^2/\[CapitalDelta]}], 
              AxesLabel \[Rule] {"\<\>", "\<\[Epsilon]\>"}, 
              PlotStyle \[Rule] {PointSize[0.015], Hue[1]}, 
              DisplayFunction \[Rule] 
                Identity];\[IndentingNewLine]];\)\)}], "Input"],

Cell[TextData[{
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox["Meaning of parameters:",
    FontFamily->"Albertus Extra Bold CE",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox["\n",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["n:\t\tdimension of Hamilon-matrix\n\[CapitalDelta]:\t\tstep size \
of finte differences in spacial derivatives\nm:\t\tquantum number\n",
    FontFamily->"Albertus Medium CE",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  CellDingbat->"\[ClubSuit]",
  FontSize->14,
  FontColor->RGBColor[0, 0, 1]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

Exact solution\
\>", "Section"],

Cell[TextData[{
  StyleBox["\nBy replacing the vaiable", "Text"],
  " \[Xi]",
  StyleBox[" by z=", "Text"],
  "\[Xi]",
  StyleBox["-", "Text"],
  "\[Epsilon], ",
  StyleBox["he ", "Text"],
  StyleBox["Schr\[ODoubleDot]dinger-Equation", "Text",
    CellFrame->True,
    FontFamily->"Albertus Extra Bold CE"],
  StyleBox["\n\n", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(-\[CapitalPhi]''\) \((\[Xi])\) + \ \[Xi]\ \ \(\
\[CapitalPhi](\[Xi])\)\ \ \  = \ \ \ \[Epsilon]\ \ \ \(\[CapitalPhi](\[Xi])\)\
\)],
    FontColor->GrayLevel[0]],
  StyleBox[" ;\n\n",
    FontColor->GrayLevel[0]],
  StyleBox["can be written as\n\n", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(-\[CapitalPhi]\&~''\) \((z)\) + \ 
          z\ \ \(\(\[CapitalPhi]\&~\)(z)\)\ \ \  = \ \ \ 0\)],
    FontColor->GrayLevel[0]],
  StyleBox[";",
    FontColor->GrayLevel[0]],
  StyleBox["\n", "Text"]
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  TextJustification->0,
  FontFamily->"Albertus Medium CE",
  FontSize->15,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(Block[{z, y}, 
      DSolve[\(-\(y''\)[z]\) + z\ y[z] == 0, y[z], z]]\)\)\)], "Input"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(Block[{z, airygraph}, 
      airygraph = 
        Plot[{AiryAi[z], AiryBi[z]}, {z, \(-3\), 2}, 
          DisplayFunction \[Rule] Identity]; 
      Show[airygraph\ , 
        Graphics[{Text["\<Ai(z)\>", {\(-2.1\), 0.4}, 
              TextStyle \[Rule] {FontColor \[Rule] Hue[0.6]}], 
            Text["\<Bi(z)\>", {0.8, 1.4}, 
              TextStyle \[Rule] {FontColor \[Rule] Hue[1]}]}], 
        PlotRange \[Rule] {{\(-3\), 2}, {\(-0.5\), 2}}, 
        DisplayFunction \[Rule] $DisplayFunction, 
        AxesLabel \[Rule] {"\<z\>", "\<\>"}];\[IndentingNewLine]]\)\)\)], \
"Input"],

Cell[TextData[{
  StyleBox["\n", "Text"],
  "As Bi(z) goes to infinity for z\[Rule]\[Infinity] , the physical solution \
is \[CapitalPhi](\[Xi])=C Ai(\[Xi]",
  StyleBox["-", "Text"],
  "\[Epsilon]). \nAs \[CapitalPhi](0) has to be 0 because of (*), the zeros \
of Ai(z) detemine the eigenvalues \[Epsilon]. For negative z \
(Ai(z)\[NotEqual]0 for z>0), ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(1\/\(3  \[Pi]\)\)\ \(cos(\(2\/3\) \((\(-z\))\)\^\
\(3\/2\) - \[Pi]\/4)\)\)]],
  " is a good approximation for Ai(z)."
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  TextJustification->0,
  FontFamily->"Albertus Medium CE",
  FontSize->15,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.849989]],

Cell[BoxData[
    RowBox[{"\[IndentingNewLine]", 
      RowBox[{"Block", "[", 
        RowBox[{\({z, airygraph}\), ",", 
          
          RowBox[{\(airygraph\  = 
              Plot[AiryAi[z], {z, \(-13\), 10}, PlotStyle \[Rule] {Hue[0.6]}, 
                DisplayFunction \[Rule] Identity]\), ";", 
            "\[IndentingNewLine]", \(airygraph\  = 
              Show[airygraph\ , 
                Plot[\(\@\(1\/\(3  Pi\)\)\) 
                    Cos[2/3\ \ \((\(-z\))\)^\((3/2)\) - Pi/4], {z, \(-13\), 
                    0}, PlotStyle \[Rule] {Hue[1]}, 
                  DisplayFunction \[Rule] Identity]]\), ";", 
            "\[IndentingNewLine]", 
            RowBox[{"Show", "[", 
              RowBox[{"airygraph", " ", ",", 
                RowBox[{"Graphics", "[", 
                  RowBox[{"{", 
                    
                    RowBox[{\(Text["\<Ai(z)\>", {2.5, 0.2}, 
                        TextStyle \[Rule] {FontColor \[Rule] Hue[0.6]}]\), 
                      ",", 
                      RowBox[{"Text", "[", 
                        RowBox[{
                        "\"\<\!\(TraditionalForm\`\(\@\(1\/\(3  \[Pi]\)\)\) \
\(cos(\(2\/3\) \((\(-z\))\)\^\(3\/2\) - \[Pi]\/4)\)\)\>\"", 
                          ",", \({\(-8\), 0.5}\), 
                          ",", \(TextStyle \[Rule] {FontSize \[Rule] \ 8, 
                              FontColor \[Rule] Hue[1]}\)}], "]"}]}], "}"}], 
                  "]"}], ",", \(PlotRange \[Rule] {{\(-13\), 10}, {\(-0.5\), 
                      1}}\), ",", \(DisplayFunction \[Rule] \
$DisplayFunction\), ",", \(AxesLabel \[Rule] {"\<z\>", "\<\>"}\)}], "]"}], 
            ";"}]}], "\[IndentingNewLine]", "]"}]}]], "Input"],

Cell[TextData[{
  StyleBox["\n", "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\(\(\@\(1\/\(3  \[Pi]\)\)\)\(\ \)\(cos(\(2\/3\) \
\((\(-z\))\)\^\(3\/2\) - \[Pi]\/4)\)\(\ \)\)\)]],
  "=0 for ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(-\((\((n - 1\/4)\) \(3  \[Pi]\)\/2)\)\^\(2/3\)\
\)\)]],
  ", therefore the eigenvalues can be approximated by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\&~\_n\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\((\((n - 1\/4)\) \(3  \[Pi]\)\/2)\)\^\(2/3\)\)]],
  ". These approximate eigenvalues ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\&~\_n\)]],
  " can be used as startingpoints to find the exact solution. The constant C \
is given by:\n",
  Cell[BoxData[
      \(TraditionalForm\`1\/C\_n\%2 = \[Integral]\_0\%\[Infinity]\(\(|\)\(Ai(\
\[Xi] - \[Epsilon]\_n)\)\( | \^2\)\(\[DifferentialD]\[Xi]\)\)\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(\[Epsilon]\_n\)\%\[Infinity]\(\(|\)\(\
Ai(z)\)\( | \^2\)\(\[DifferentialD]z\)\)\)]]
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  TextJustification->0,
  FontFamily->"Albertus Medium CE",
  FontSize->15,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.849989]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Definition:",
  FontColor->RGBColor[1, 0, 0]]], "Subsection",
  CellDingbat->"\[LightBulb]",
  TextAlignment->AlignmentMarker,
  FontFamily->"Albertus Medium CE",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[{
    \(\(ExactEigenvalue[m_] := 
        Block[{x0, xy}, \[IndentingNewLine]\t\t\t\t\t\t\tx0\  = \ 
            N[\((\((2  m - 1\/2)\) \(\[Pi]\ 3\)\/4)\)\^\(2/3\)]; \
\[IndentingNewLine]\t\t\t\t\t\t\txy /. 
            FindRoot[
              AiryAi[xy] \[Equal] 
                0, {xy, \(-x0\)}]\[IndentingNewLine]\t\t\t\t\t\t];\)\), "\n", \

    \(\(ExactMean[m_] := \ 
        Block[{\[Lambda], 
            x}, \[IndentingNewLine]\t\t\t\t\t\[Lambda] = \(-ExactEigenvalue[
                m]\); \[IndentingNewLine]\t\t\t\t\tN[\[Integral]\_\(\(0\)\(\ \
\ \)\)\%\(\(\[Infinity]\)\(\ \ \)\)x\ \ \ \(AiryAi[x - \[Lambda]]\^2\) \
\[DifferentialD]x]\/N[\[Integral]\_0\%\[Infinity]\ \ \ AiryAi[x - \
\[Lambda]]\^2\ \ \ \[DifferentialD]x]\[IndentingNewLine]\t\t\t\ \ \ \ \t\ \ \ \
];\)\), "\[IndentingNewLine]", 
    \(\(Compare[n_, xmax_, nEig_] := 
        Block[{x, \[Lambda]}, \[IndentingNewLine]\t\t\t\t\t\t\t\t\
\[CapitalPsi][n, xmax, 
            n + 1 - nEig]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\[Lambda]\ \ \ \
\ \ \ \ \  = \(-ExactEigenvalue[
                nEig]\); \[IndentingNewLine]\t\t\t\t\t\t\t\tnorm\  = 
            N[\[Integral]\_0\%\[Infinity] AiryAi[x - \[Lambda]]\^2\
\ \ \ \[DifferentialD]x]; \[IndentingNewLine]\t\t\t\t\t\t\t\tp2\ \ \ \ \  = 
            Plot[AiryAi[x - \[Lambda]]\^2/norm, {x, 0, Max[xmax, 8]}, 
              PlotStyle \[Rule] {Hue[0.6]}, 
              DisplayFunction \[Rule] 
                Identity]; \[IndentingNewLine]\t\t\t\t\t\t\t\tShow[{p1, p2}, 
            AxesLabel \[Rule] {"\<x\>", \*"\"\<|\[CapitalPsi](x)\!\(\( | \
\^2\)\)\>\""}, 
            DisplayFunction \[Rule] $DisplayFunction];\[IndentingNewLine]\t\t\
\t\t\t\t\t];\)\)}], "Input"],

Cell[TextData[{
  StyleBox[" ",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox["Meaning of parameters:",
    FontFamily->"Albertus Extra Bold CE",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox["\nm",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox[":\t\tquantum number\nn:\t\tdimension of Hamilon-matrix\n",
    FontFamily->"Albertus Medium CE",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(TraditionalForm\`xmax\)]],
  StyleBox[":\tmaximal x-coordinate included in descretized region",
    FontFamily->"Albertus Medium CE",
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  CellDingbat->"\[ClubSuit]",
  FontSize->14,
  FontColor->RGBColor[0, 0, 1]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Groundstate and low-lying excited states",
  FontFamily->"Times"]], "Section",
  CellFrame->{{0, 0}, {2, 0}},
  FontFamily->"Albertus Medium CE"],

Cell[CellGroupData[{

Cell[TextData[{
  "This Section gives a comparison of the results obtained with a discrete \
Matrix and the exact results for the lowest three eigenstates.\n\nPlot of all \
eigenvalues plus numerical values of lowest  3 eigenvalues and corresponding \
averages < ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalPsi]\_n | 
        x | \(\(\[CapitalPsi]\_n\)\(>\)\)\)]]
}], "Subsection",
  CellDingbat->"\[WatchIcon]",
  FontFamily->"Albertus Medium CE"],

Cell[BoxData[
    StyleBox[\(Eigen[nd, xmaxd]\),
      "Subsection"]], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "Comparison of Wavefunktions ",
  StyleBox["Finite Differences",
    FontColor->RGBColor[1, 0, 0]],
  StyleBox["  ",
    FontColor->RGBColor[0, 0, 1]],
  "<->",
  StyleBox[" Exakt solution ",
    FontColor->RGBColor[0, 0, 1]],
  "for quantum numbers n=1,2,3"
}], "Subsection",
  CellDingbat->"\[WatchIcon]",
  FontFamily->"Albertus Medium CE"],

Cell[CellGroupData[{

Cell[TextData[StyleBox["1) Groundstate",
  FontFamily->"Albertus Medium CE"]], "Subsubsection",
  CellDingbat->None,
  TextAlignment->Left],

Cell[BoxData[
    \(\(Compare[nd, xmaxd, 1];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["2) First excited state", "Subsubsection",
  CellDingbat->None,
  TextAlignment->Left,
  FontFamily->"Albertus Medium CE"],

Cell[BoxData[
    \(\(Compare[nd, xmaxd, 2];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["3) Second excited state", "Subsubsection",
  CellDingbat->None,
  TextAlignment->Left,
  FontFamily->"Albertus Medium CE"],

Cell[BoxData[
    \(\(Compare[nd, xmaxd, 3];\)\)], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Dynamics", "Section",
  CellFrame->{{0, 0}, {2, 0}},
  FontFamily->"Albertus Medium CE"],

Cell[CellGroupData[{

Cell["Definition:", "Subsection",
  CellDingbat->"\[LightBulb]",
  FontFamily->"Albertus Medium CE",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[{
    \(Needs["\<Graphics`MultipleListPlot`\>"]\), "\n", 
    \(\(\(OneStep[DM_, x_, xmax_, \[CapitalPhi]_, n_, x_] := 
        Block[{p1, p2, 
            xmean}, \[IndentingNewLine]\t\t\t\t\t\t\t\t\ \ xmean = \ 
            x\  . Abs[\[CapitalPhi]]^2/\((Abs[\[CapitalPhi]]\  . 
                  Abs[\[CapitalPhi]])\); \[IndentingNewLine]\t\t\t\t\t\t\t\t\ \
\ app\ \ \ \ \  = \ {{xmean, 0}, {xmean, 
                1}}; \[IndentingNewLine]\t\t\t\t\t\t\t\t\ \ yyy\ \ \ \ \ \  = \
\ Join[Transpose[{x, Abs[\[CapitalPhi]]\^2}], 
              app]; \[IndentingNewLine]\t\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \
ListPlot[yyy, PlotRange -> {{0, xmax}, {0, 1}}, PlotStyle \[Rule] {Hue[1]}, 
            PlotJoined -> True, 
            AxesLabel \[Rule] {"\<x\>", \*"\"\<|\[CapitalPhi]\!\(\( | \^2\)\)\
\>\""}]; \[IndentingNewLine]\t\t\t\t\t\t\t\ \ \ \ \ \ \ \ \ \ \ \ DM . \
\[CapitalPhi]];\)\(\n\)
    \)\), "\n", 
    \(\(\(dyn[n_, xmax_, Nt_, Nper_, x0_, \[Sigma]_] := 
        Block[{\[CapitalDelta] = xmax/n, dt = Nper*2 \@ x0/Nt}, 
          H = N[M[n, xmax]]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\tx = 
            Table[i\ \[CapitalDelta], {i, 1, 
                n}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\[CapitalPhi] = \
\[ExponentialE]\^\(-\(\((x - x0)\)\^2\/\(2\ \[Sigma]\^2\)\)\)\/\((\[Pi]\ \
\[Sigma])\)\^\(1/4\)\ ; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\ DM = 
            MatrixExp[\[ImaginaryI]\ dt\ H]; \[IndentingNewLine]\t\t\t\t\t\t\t\
\t\t\ Table[\(\[CapitalPhi] = 
                OneStep[DM, x, xmax, \[CapitalPhi], n, x]\ ;\)\ , {i, 1, 
              Nt}]; \[IndentingNewLine]SelectionMove[EvaluationNotebook[], 
            After, EvaluationCell]; \[IndentingNewLine]SelectionMove[
            EvaluationNotebook[], Next, 
            CellGroup]; \
\[IndentingNewLine]FrontEndTokenExecute["\<OpenCloseGroup\>"]\
\[IndentingNewLine]\t\t\t\t\t\t\t\t];\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(DynMean[n_, xmax_, Nt_, Nper_, x0_, \[Sigma]_] := 
        Block[{\[CapitalDelta] = xmax/n, x, \[CapitalPhi], DM, tavg, \ tarr, 
            tp, p1, tmax = Nper*2 \@ x0, 
            dt = tmax/
                Nt}, \[IndentingNewLine]\t\t\t\t\t\t\t\t\tH\ \ \ \ \ \ \ \ \ \
\ \ \ \  = N[M[n, 
                xmax]]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\tx\ \ \ \ \ \ \ \ \
\ \ \ \ \  = 
            Table[i\ \[CapitalDelta], {i, 1, 
                n}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\[CapitalPhi]\ \ \ \
\ \ \ \ \ \ \ \ \ \  = \[ExponentialE]\^\(-\(\((x - x0)\)\^2\/\(2\ \
\[Sigma]\^2\)\)\)\/\((\[Pi]\ \[Sigma])\)\^\(1/4\)\ ; \[IndentingNewLine]\t\t\t\
\t\t\t\t\t\tDM\ \ \ \ \ \ \ \ \ \  = 
            MatrixExp[\[ImaginaryI]\ dt\ H]; \[IndentingNewLine]\t\t\t\t\t\t\t\
\t\ttavg\ \ \ \ \  = 
            Table[\[CapitalPhi] = DM . \[CapitalPhi]; 
              x\  . Abs[\[CapitalPhi]]^2/\((Abs[\[CapitalPhi]]\  . 
                    Abs[\[CapitalPhi]])\), {Nt}]; \[IndentingNewLine]\t\t\t\t\
\t\t\t\t\ttarr\ \ \ \ \  = \ 
            Table[i\ dt, {i, 1, 
                Nt}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\ttp\ \ \ \ \ \ \ \ \
\ \  = \ \@x0; \[IndentingNewLine]\t\t\t\t\t\t\t\t\tp1\ \ \ \ \ \ \ \ \ \  = 
            Plot[x0 - \((Mod[t - tp, 2\ tp] - tp)\)\^2, {t, 0, 
                tmax}, \[IndentingNewLine]\t\t\t\t\t\t\t\t\ \ \ \ \ PlotStyle \
\[Rule] {Hue[0.3, 0.8, 0.5]}, 
              DisplayFunction \[Rule] 
                Identity]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\tp2\ \ \ \ \ \ \
\ \ \ \ \  = 
            Show[p1, 
              ListPlot[
                Transpose[{tarr, 
                    tavg}], \[IndentingNewLine]\t\t\t\t\t\t\t\ \ \ \ \ \ \ \ \
\ \ \ \ PlotRange \[Rule] {{0, tmax}, {0, x0*1.1}}, 
                PlotStyle \[Rule] {PointSize[0.01], 
                    Hue[1]}, \[IndentingNewLine]\t\t\t\t\t\t\t\t\ \ \
DisplayFunction \[Rule] Identity], \ 
              DisplayFunction \[Rule] 
                Identity]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\tShow[p2, 
            Graphics[\[IndentingNewLine]\t\t\t\t\t\t\t\t\ \ \ \ \
{Text["\<class.\>", {tmax*1.05, \((x0 - \((Mod[tmax - tp, 2\ tp] - \
tp)\)\^2)\)*1.05}, \[IndentingNewLine]\t\t\t\t\t\t\t\tTextStyle \[Rule] \
{FontColor \[Rule] Hue[0.3, 0.8, 
                          0.5]}], \[IndentingNewLine]\t\t\t\t\t\t\t\t\ \ \
Text["\<QM\>", {tmax*1.05, 0.95*tavg[\([Nt]\)]}, 
                  TextStyle \[Rule] {FontColor \[Rule] 
                        Hue[1]}]}], \[IndentingNewLine]\t\t\t\t\t\t\t\t\ \ \ \
\ \ \ \ PlotRange \[Rule] {{0, tmax*1.1}, {0, x0*1.1}}, 
            AxesLabel \[Rule] {"\<t\>", "\<<x>(t)\>"}, 
            
            DisplayFunction \[Rule] $DisplayFunction];\[IndentingNewLine]\t\t\
\t\t\t\t\t];\)\), "\n", 
    \(\(ExactDyn[n_, xmax_, Nt_, Nper_, x0_, \[Sigma]_, 
          Mmax_] := \[IndentingNewLine]\t\t\t\t\t\t\tBlock[{\[CapitalDelta] = 
              xmax/n, tp, tavg, tarr, p1, p2, x, zeroes, normq, coeff, y, 
            sq = 2\ \[Sigma]\^2, 
            dt = Nper*2 \@ x0/Nt}, \[IndentingNewLine]\t\t\t\t\t\t\t\t\tOff[
            NIntegrate::ncvb]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\tx\ \ \ \ \
\ \ \ \ \ \ \ \  = 
            Table[i\ \[CapitalDelta], {i, 
                n}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\tzeroes = 
            Table[\(-ExactEigenvalue[m]\), {m, 
                Mmax}]; \[IndentingNewLine] (*\(Print[
                zeroes];\)*) \[IndentingNewLine]\t\t\t\t\t\t\t\t\tnormq\ \ \ \
\  = \ NIntegrate[
              AiryAi[xx - zeroes[\([1]\)]]\^2, {xx, 
                0, \[Infinity]}]\ ;  (*norm\^2\ of\ 1\^st\ eigenfct\
*) \[IndentingNewLine]\t\t\t\t\t\t\t\t\tcoeff\ \  = \ \ NIntegrate[AiryAi[xx \
- zeroes[\([1]\)]]\ \[ExponentialE]\^\(-\(\((xx - x0)\)\^2\/sq\)\), {xx, 0, \
\[Infinity]}]\/\(\(normq\ \((\[Pi]\ \[Sigma]\^2)\)\^\(1/4\)\)\(\
\[IndentingNewLine]\)
              \); \[IndentingNewLine]\t\t\t\t\t\t\t\t\tDo[\[IndentingNewLine]\
\t\t\t\t\t\t\t\t\t\ty[m - 1]\  = \ \ AiryAi[x - zeroes[\([m - 1]\)]]\ *\ 
                coeff; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\tnormq\ \ \ \ \ \
\ \ \  = normq\  + \ \ NIntegrate[
                  AiryAi[xx]\^2, {xx, \(-zeroes[\([m]\)]\), \(-zeroes[\([m - 
                            1]\)]\)}]\ ; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\
\tcoeff\ \ \ \ \ \  = \ \ NIntegrate[AiryAi[xx - zeroes[\([m]\)]]\ \
\[ExponentialE]\^\(-\(\((xx - x0)\)\^2\/sq\)\), {xx, 0, \
\[Infinity]}]\/\(normq\ \((\[Pi]\ \[Sigma]\^2)\)\^\(1/4\)\);\
\[IndentingNewLine]\t\t\t\t\t\t\t\t\t\ \ , {m, 2, 
              Mmax}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\ty[
              Mmax]\  = \ \ AiryAi[x - zeroes[\([Mmax]\)]]\ *\ 
              coeff; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t (*\(tavg\  = \ 
                Table[0, {tmax/
                      dt}];\)*) \[IndentingNewLine]\t\t\t\t\t\t\t\t\tyy\ \ \  \
= \ x*0; \[IndentingNewLine]\t\t\t\t\t\t\t\t\tDo[
            yy\  = \ yy\  + \ \ \ y[m], {m, 1, 
              Mmax}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\tt0\ \ \  = 
            Transpose[{x, 
                Abs[yy]\^2}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\txa\ \ \  = \
\ x\  . Abs[yy]\^2/\((Abs[yy]\  . 
                  Abs[yy])\); \[IndentingNewLine]\t\t\t\t\t\t\t\t\tva0\  = \ \
\@\(\(\(x\)\(\ \)\)\^2 . Abs[yy]\^2/\((Abs[yy]\  . Abs[yy])\) - xa\^2\); \
\[IndentingNewLine]\t\t\t\t\t\t\t\t\tta0\  = \ {{xa, 0}, {xa, 
                1}}; \n\t\t\t\t\t\t\t\t\tDo[\[IndentingNewLine]\t\t\t\t\t\t\t\
\t\t\tyy\ \ \  = \ 
              x*0; \[IndentingNewLine] (*\(Print[
                  Exp[\(-\[ImaginaryI]\)\ dt*\ nt*zeroes[\([2]\)]]/
                    Exp[\(-\[ImaginaryI]\)\ dt*\ nt*
                        zeroes[\([1]\)]]];\)*) \[IndentingNewLine]\t\t\t\t\t\t\
\t\t\t\tDo[yy\  = \ 
                yy\  + \ \ Exp[\(-\[ImaginaryI]\)\ dt*\ nt*
                        zeroes[\([m]\)]]\ *\ \ y[m], {m, 1, 
                Mmax}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\tt1\ \ \  = \ 
              Transpose[{x, 
                  Abs[yy]\^2}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\txa\ \ \
\  = \ x\  . Abs[yy]\^2/\((Abs[yy]\  . 
                    Abs[yy])\); \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\tva\ \ \
\  = \ \@\(\(\(x\)\(\ \)\)\^2 . Abs[yy]\^2/\((Abs[yy]\  . Abs[yy])\) - \
xa\^2\); \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\tta\ \ \  = \ {{xa, 0}, {xa, 
                  1}}; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\ttv\ \ \  = \ \
{{xa - va,  .99}, {xa + 
                    va,  .99}}; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\ttv0\  \
= \ {{xa - va0, 1}, {xa + va0, 
                  1}}; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\t\
MultipleListPlot[t1, ta, tv, t0, ta0, tv0, 
              PlotJoined \[Rule] 
                True, \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\t\tPlotStyle \
\[Rule] {Hue[1], Hue[1], Hue[1], Hue[ .6], Hue[ .6], 
                  Hue[ .6]}, \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\t\t\
SymbolShape \[Rule] None, PlotRange -> {{0, n\ \[CapitalDelta]}, {0, 1}}, 
              AxesLabel \[Rule] {"\<x\>", \*"\"\<|\[CapitalPhi]\!\(\( | \^2\)\
\)\>\""}];\[IndentingNewLine]\t\t\t\t\t\t\t\t\t\t (*\(avg[\([nt]\)] = 
                  x\  . Abs[yy]\^2/\((Abs[yy]\  . 
                        Abs[yy])\);\)*) \[IndentingNewLine]\t\t\t\t\t\t\t\t\t\
, {nt, 0, Nt}]; \[IndentingNewLine]SelectionMove[EvaluationNotebook[], After, 
            EvaluationCell]; \[IndentingNewLine]SelectionMove[
            EvaluationNotebook[], Next, 
            CellGroup]; \
\[IndentingNewLine]FrontEndTokenExecute["\<OpenCloseGroup\>"]; \
\[IndentingNewLine]\t\t\t\t\t\t\t\t\tOn[
            NIntegrate::ncvb]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\t (*tarr\ \
\ \ \ \ \  = \ 
              Table[\((nt - 1)\) dt, {nt, 1, 
                  tmax/dt}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\ttp\ \ \ \ \ \
\ \ \ \ \  = \ \@x0; \[IndentingNewLine]\t\t\t\t\t\t\t\t\tp1\ \ \ \ \ \ \ \ \ \
\  = Plot[x0 - \((Mod[t - tp, 2\ tp] - tp)\)\^2, {t, 0, 
                  tmax}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\tp2\ \ \ \ \ \ \
\ \ \ \  = ListPlot[Transpose[{tarr, tavg}], 
                PlotRange \[Rule] {{0, tmax}, {0, 
                      x0*1.1}}]; \[IndentingNewLine]\t\t\t\t\t\t\t\t\ \ \ \ \ \
\ \ \ \ Show[{p1, p2}];*) \[IndentingNewLine]\t\t\t\t\t\t\t\t];\)\)}], "Input"],

Cell[TextData[{
  StyleBox["Mea",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox["ning of parameter:",
    FontFamily->"Albertus Extra Bold CE",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True}],
  StyleBox["\nn:\t\tdimension of Hamilon-matrix\n\t\tin DynExact only needed \
for plot-resolution\n",
    FontColor->RGBColor[0, 0, 1]],
  Cell[BoxData[
      \(TraditionalForm\`xmax\)]],
  StyleBox[":\tmaximal x-coordinate included in descretized region",
    FontFamily->"Albertus Medium CE",
    FontColor->RGBColor[0, 0, 1]],
  StyleBox["\nNt:\t\t# of time steps\nNper:\tNumber of Periods \nx0:\t\t\
center of initial gaussian wave-package\n\[Sigma]:\t\twidth of initial \
gaussian wave-package\nMmax:\t\tmax # of states included in spectral theorem",
    
    FontColor->RGBColor[0, 0, 1]]
}], "Subsubsection",
  CellDingbat->"\[ClubSuit]",
  FontFamily->"Albertus Medium CE",
  FontSize->14,
  FontColor->RGBColor[0, 0, 1]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Time-evolution of gaussian wave-package", "Subsection",
  CellDingbat->"\[WatchIcon]",
  FontFamily->"Albertus Medium CE"],

Cell[BoxData[
    \(\(dyn[nd, xmaxd, Nt0, Nper, x0, \[Sigma]0];\)\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Time-evolution of <x>", "Subsection",
  CellDingbat->"\[WatchIcon]",
  FontFamily->"Albertus Medium CE"],

Cell[BoxData[
    \(DynMean[nd, xmaxd, Nt0, Nper, x0, \[Sigma]0]\)], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Continuum dynamics (no finite differences!)", "Subsection",
  CellDingbat->"\[WatchIcon]",
  FontFamily->"Albertus Extra Bold CE"],

Cell[BoxData[{
    \(\(Off[General::unfl];\)\), "\[IndentingNewLine]", 
    \(\(ExactDyn[nd, xmaxd, Nt0, Nper, x0, \[Sigma]0, Mmaxe];\)\)}], "Input"],

Cell["\<\

The red curves show the developpment of the wave function, the expectetion \
value  and the variance of the particle's position., the blue curves give the \
initial wave packet and expectation value. If the blue wave function does not \
look gaussian, Mmaxe is probably too small!\
\>", "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->"EditBar",
WindowSize->{1269, 920},
WindowMargins->{{0, Automatic}, {Automatic, 24}},
PrintingPageRange->{Automatic, Automatic},
PrintingOptions->{"PaperSize"->{597.562, 842.375},
"PaperOrientation"->"Portrait",
"PostScriptOutputFile":>FrontEnd`FileName[{$RootDirectory, "itp", "faeppc32", \
"u3", "daghofer", "mathem"}, "fall2.nb.ps", CharacterEncoding -> \
"ISO8859-1"],
"Magnification"->1},
Magnification->1,
StyleDefinitions -> "PastelColor.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 146, 4, 111, "Title"],

Cell[CellGroupData[{
Cell[1898, 60, 62, 4, 66, "Section"],

Cell[CellGroupData[{
Cell[1985, 68, 52, 3, 54, "Subsection"],
Cell[2040, 73, 225, 8, 48, "Text"],
Cell[2268, 83, 87, 1, 51, "Input"],
Cell[2358, 86, 253, 6, 48, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[2648, 97, 39, 3, 54, "Subsection"],
Cell[2690, 102, 200, 10, 48, "Text"],
Cell[2893, 114, 88, 1, 51, "Input"],
Cell[2984, 117, 80, 4, 48, "Text"],
Cell[3067, 123, 336, 11, 48, "Text"],
Cell[3406, 136, 83, 1, 51, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[3538, 143, 61, 1, 55, "Section"],
Cell[3602, 146, 3605, 98, 499, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[7244, 249, 70, 1, 55, "Section"],
Cell[7317, 252, 2076, 66, 289, "Text"],

Cell[CellGroupData[{
Cell[9418, 322, 95, 2, 38, "Subsection"],
Cell[9516, 326, 358, 6, 75, "Input"],
Cell[9877, 334, 647, 18, 84, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10561, 357, 67, 1, 38, "Subsection"],
Cell[10631, 360, 57, 1, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10725, 366, 218, 5, 37, "Subsection"],
Cell[10946, 373, 2671, 46, 317, "Input"],
Cell[13620, 421, 634, 17, 102, "Subsubsection"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[14303, 444, 42, 3, 66, "Section"],
Cell[14348, 449, 1077, 34, 221, "Text"],
Cell[15428, 485, 133, 2, 51, "Input"],
Cell[15564, 489, 631, 13, 99, "Input"],
Cell[16198, 504, 717, 19, 111, "Text"],
Cell[16918, 525, 1701, 33, 199, "Input"],
Cell[18622, 560, 1222, 34, 114, "Text"],

Cell[CellGroupData[{
Cell[19869, 598, 218, 5, 37, "Subsection"],
Cell[20090, 605, 1710, 32, 363, "Input"],
Cell[21803, 639, 750, 21, 86, "Subsubsection"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[22602, 666, 169, 3, 55, "Section"],

Cell[CellGroupData[{
Cell[22796, 673, 457, 10, 67, "Subsection"],
Cell[23256, 685, 79, 2, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23372, 692, 361, 12, 37, "Subsection"],

Cell[CellGroupData[{
Cell[23758, 708, 139, 3, 28, "Subsubsection"],
Cell[23900, 713, 59, 1, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23996, 719, 127, 3, 28, "Subsubsection"],
Cell[24126, 724, 59, 1, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[24222, 730, 128, 3, 28, "Subsubsection"],
Cell[24353, 735, 59, 1, 35, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[24473, 743, 94, 2, 55, "Section"],

Cell[CellGroupData[{
Cell[24592, 749, 132, 3, 37, "Subsection"],
Cell[24727, 754, 10149, 175, 1693, "Input"],
Cell[34879, 931, 991, 25, 169, "Subsubsection"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35907, 961, 128, 2, 37, "Subsection"],
Cell[36038, 965, 78, 1, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36153, 971, 110, 2, 37, "Subsection"],
Cell[36266, 975, 77, 1, 35, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36380, 981, 136, 2, 37, "Subsection"],
Cell[36519, 985, 149, 2, 51, "Input"],
Cell[36671, 989, 305, 6, 68, "Text"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

